(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    227878,       5275]*)
(*NotebookOutlinePosition[    273364,       6768]*)
(*  CellTagsIndexPosition[    273320,       6764]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["DecisionModels\n",
    FontSlant->"Italic"],
  StyleBox["Erl\[ADoubleDot]uternde Beispiele zum Paket ",
    FontSize->24]
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["\[Copyright] Alfred Schreiber  |  2004-07-02",
  FontFamily->"Arial"]], "SmallText",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Das Paket ",
  StyleBox["DecisionModels",
    FontSlant->"Italic"],
  " laden:"
}], "Text"],

Cell[BoxData[
    \(Needs["\<DecisionModels`DecisionModels`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["1. Datenaufbereitung", "Section"],

Cell[CellGroupData[{

Cell["Entscheidungsmatrix", "Subsection"],

Cell["\<\
A sei die Menge der m\[ODoubleDot]glichen Auflagen f\[UDoubleDot]r ein zu \
verlegendes Buch, B die Menge der Absatzzahlen, g die Gewinnfunktion des \
Verlegers:\
\>", "Text"],

Cell[BoxData[{
    \(\(A = {5000, 7000, 9000};\)\), "\[IndentingNewLine]", 
    \(\(B = {4000, 5000, 6000, 7000, 8000, 
          9000};\)\), "\[IndentingNewLine]", 
    \(\(g[x_, y_] := Min[x, y]*15 - 10  x - 10000;\)\)}], "Input"],

Cell["\<\
Berechnung der Konsequenzen-Matrix (hier auch: Entscheidungsmatrix):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cmat = DecisionMatrix[g, A, B];\)\), "\[IndentingNewLine]", 
    \(cmat // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "15000", "15000", "15000", "15000", "15000"},
            {\(-20000\), \(-5000\), "10000", "25000", "25000", "25000"},
            {\(-40000\), \(-25000\), \(-10000\), "5000", "20000", "35000"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normierung", "Subsection"],

Cell["\<\
Die Skalentransformation bildet das Intervall [3;7] (monoton wachsend) auf \
das Intervall [1;17] ab:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(\(ScaleTransform[{3, 7}, {1, 17}]\)[x]\)\)\)], "Input"],

Cell[BoxData[
    \(\(-11\) + 4\ x\)], "Output"]
}, Open  ]],

Cell["\<\
Die Skalennormierte bildet das Intervall [3;7] (monoton wachsend) auf das \
Einheitsintervall [0;1] ab:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ScaleNorm[3, 7]\)[x]\)], "Input"],

Cell[BoxData[
    \(\(-\(3\/4\)\) + x\/4\)], "Output"]
}, Open  ]],

Cell["\<\
Der Einzelwert 5 wird der eben berechneten Skalennormierten unterworfen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NormalizeValue[5, {3, 7}]\)], "Input"],

Cell[BoxData[
    \(1\/2\)], "Output"]
}, Open  ]],

Cell["\<\
Eine Menge von Werten wird in Bezug auf das von Minimum und Maximum gebildete \
Intervall normiert:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cmat1 = NormalizeRange[cmat];\)\), "\[IndentingNewLine]", 
    \(cmat1 // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(8\/15\), \(11\/15\), \(11\/15\), \(11\/15\), \(11\/15\), \
\(11\/15\)},
            {\(4\/15\), \(7\/15\), \(2\/3\), \(13\/15\), \(13\/15\), \(13\/15\
\)},
            {"0", \(1\/5\), \(2\/5\), \(3\/5\), \(4\/5\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Definition einer Funktion und Darstellung ihres Graphen:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[x_] := \(-2\) + x + 3  x^2;\)\), "\[IndentingNewLine]", 
    \(\(Plot[f[x], {x, \(-1\), 2}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.161797 0.0705992 [
[.02381 .1493 -6 -9 ]
[.02381 .1493 6 0 ]
[.18254 .1493 -12 -9 ]
[.18254 .1493 12 0 ]
[.5 .1493 -9 -9 ]
[.5 .1493 9 0 ]
[.65873 .1493 -3 -9 ]
[.65873 .1493 3 0 ]
[.81746 .1493 -9 -9 ]
[.81746 .1493 9 0 ]
[.97619 .1493 -3 -9 ]
[.97619 .1493 3 0 ]
[.32877 .0206 -12 -4.5 ]
[.32877 .0206 0 4.5 ]
[.32877 .30299 -6 -4.5 ]
[.32877 .30299 0 4.5 ]
[.32877 .44419 -6 -4.5 ]
[.32877 .44419 0 4.5 ]
[.32877 .58539 -6 -4.5 ]
[.32877 .58539 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .1618 m
.02381 .16805 L
s
[(-1)] .02381 .1493 0 1 Mshowa
.18254 .1618 m
.18254 .16805 L
s
[(-0.5)] .18254 .1493 0 1 Mshowa
.5 .1618 m
.5 .16805 L
s
[(0.5)] .5 .1493 0 1 Mshowa
.65873 .1618 m
.65873 .16805 L
s
[(1)] .65873 .1493 0 1 Mshowa
.81746 .1618 m
.81746 .16805 L
s
[(1.5)] .81746 .1493 0 1 Mshowa
.97619 .1618 m
.97619 .16805 L
s
[(2)] .97619 .1493 0 1 Mshowa
.125 Mabswid
.05556 .1618 m
.05556 .16555 L
s
.0873 .1618 m
.0873 .16555 L
s
.11905 .1618 m
.11905 .16555 L
s
.15079 .1618 m
.15079 .16555 L
s
.21429 .1618 m
.21429 .16555 L
s
.24603 .1618 m
.24603 .16555 L
s
.27778 .1618 m
.27778 .16555 L
s
.30952 .1618 m
.30952 .16555 L
s
.37302 .1618 m
.37302 .16555 L
s
.40476 .1618 m
.40476 .16555 L
s
.43651 .1618 m
.43651 .16555 L
s
.46825 .1618 m
.46825 .16555 L
s
.53175 .1618 m
.53175 .16555 L
s
.56349 .1618 m
.56349 .16555 L
s
.59524 .1618 m
.59524 .16555 L
s
.62698 .1618 m
.62698 .16555 L
s
.69048 .1618 m
.69048 .16555 L
s
.72222 .1618 m
.72222 .16555 L
s
.75397 .1618 m
.75397 .16555 L
s
.78571 .1618 m
.78571 .16555 L
s
.84921 .1618 m
.84921 .16555 L
s
.88095 .1618 m
.88095 .16555 L
s
.9127 .1618 m
.9127 .16555 L
s
.94444 .1618 m
.94444 .16555 L
s
.25 Mabswid
0 .1618 m
1 .1618 L
s
.34127 .0206 m
.34752 .0206 L
s
[(-2)] .32877 .0206 1 0 Mshowa
.34127 .30299 m
.34752 .30299 L
s
[(2)] .32877 .30299 1 0 Mshowa
.34127 .44419 m
.34752 .44419 L
s
[(4)] .32877 .44419 1 0 Mshowa
.34127 .58539 m
.34752 .58539 L
s
[(6)] .32877 .58539 1 0 Mshowa
.125 Mabswid
.34127 .0559 m
.34502 .0559 L
s
.34127 .0912 m
.34502 .0912 L
s
.34127 .1265 m
.34502 .1265 L
s
.34127 .1971 m
.34502 .1971 L
s
.34127 .2324 m
.34502 .2324 L
s
.34127 .2677 m
.34502 .2677 L
s
.34127 .33829 m
.34502 .33829 L
s
.34127 .37359 m
.34502 .37359 L
s
.34127 .40889 m
.34502 .40889 L
s
.34127 .47949 m
.34502 .47949 L
s
.34127 .51479 m
.34502 .51479 L
s
.34127 .55009 m
.34502 .55009 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1618 m
.06244 .12197 L
.10458 .0857 L
.14415 .05842 L
.18221 .0384 L
.20178 .03047 L
.22272 .02377 L
.23293 .02117 L
.24402 .01885 L
.25449 .01713 L
.26416 .01595 L
.26882 .01552 L
.27383 .01516 L
.27626 .01502 L
.27856 .01492 L
.28063 .01484 L
.28289 .01478 L
.28429 .01475 L
.2856 .01473 L
.28679 .01472 L
.28806 .01472 L
.28873 .01472 L
.28946 .01472 L
.29023 .01472 L
.29094 .01473 L
.29222 .01475 L
.29358 .01477 L
.29486 .0148 L
.29625 .01485 L
.29878 .01494 L
.30351 .0152 L
.30836 .01556 L
.31291 .01598 L
.32329 .01728 L
.3334 .01898 L
.3443 .02129 L
.36434 .02685 L
.38544 .03452 L
.42354 .05312 L
.4641 .07962 L
.50315 .11167 L
.54465 .15275 L
.58463 .19918 L
.6231 .25019 L
.66401 .31128 L
.70342 .37676 L
.7413 .44587 L
.78164 .52609 L
.82047 .60975 L
s
.82047 .60975 m
.82403 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oT`3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo002C0?ooo`030000003oool0oooo0?l0oooo6`3oool009<0
oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00T`3oool00`000000oooo0?ooo`3o0?oooa/0oooo
002C0?ooo`030000003oool0oooo0?l0oooo6`3oool008D0oooo1P0000080?ooo`030000003oool0
oooo0?l0oooo6`3oool00700oooo6@0000000`3oool000000?ooo`070?ooo`030000003oool0oooo
0?l0oooo6`3oool006`0oooo1000000F0?ooo`030000003oool0oooo00@000001P3oool00`000000
oooo0?ooo`3o0?oooa/0oooo001W0?ooo`D000006`3oool00`000000oooo0?ooo`030?ooo`D00000
00@0oooo0000000000000000o`3ooolK0?ooo`00H`3oool4000001D0oooo1P0000060?ooo`030000
003oool0oooo00L0oooo1@00003o0?oooaX0oooo001O0?ooo`@000009P3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo0?ooo`@00000o`3ooolF0?ooo`00G03oool3000002H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo1000
003o0?oooa80oooo001I0?ooo`<00000:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool300000?l0oooo3`3oool005H0oooo0`00000]0?oo
o`@000002@3oool00`000000oooo0?ooo`0<0?ooo`<00000o`3oool<0?ooo`00D`3oool3000003d0
oooo00<000000?ooo`3oool03`3oool200000?l0oooo2P3oool00500oooo0`0000100?ooo`030000
003oool0oooo0140oooo0P00003o0?ooo`P0oooo001>0?ooo`800000@`3oool00`000000oooo0?oo
o`0C0?ooo`800000o`3oool60?ooo`00C03oool2000004D0oooo00<000000?ooo`3oool05@3oool2
00000?l0oooo103oool004X0oooo0P0000170?ooo`030000003oool0oooo01L0oooo0P00003o0?oo
o`80oooo00180?ooo`800000B@3oool00`000000oooo0?ooo`0I0?ooo`800000o`3oool004L0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0K0?ooo`800000o@3oool004D0oooo0P00
001<0?ooo`030000003oool0oooo01d0oooo0P00003k0?ooo`00@`3oool2000004h0oooo00<00000
0?ooo`3oool07`3oool200000?T0oooo00110?ooo`800000D03oool00`000000oooo0?ooo`0Q0?oo
o`800000m`3oool003l0oooo0P00001B0?ooo`800000903oool00`000000oooo0?ooo`3d0?ooo`00
?P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02@0oooo0P00003d0?ooo`00?03o
ool2000005D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3a0?ooo`00>`3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02L0oooo0P00003a0?ooo`00>@3oool20000
05P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3^0?ooo`00>03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo02X0oooo0P00003^0?ooo`00=P3oool2000005/0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3[0?ooo`00=03oool2000005d0oooo00<0
00000?ooo`3oool0;@3oool200000>/0oooo000c0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`3X0?ooo`00<@3oool200000600oooo00<000000?oo
o`3oool0<03oool200000>P0oooo000`0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`3U0?ooo`00;P3oool2000006<0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`3T0?ooo`00;@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0h`3oool002`0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0>80oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0=P3oool200000>80oooo000Z0?ooo`030000003oool0oooo06H0
oooo0P00000i0?ooo`030000003oool0oooo0=l0oooo000X0?ooo`800000J@3oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo0=h0oooo000W0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`3M0?ooo`009P3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0g03oool002D0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0=/0oooo000T0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3J0?ooo`00
8`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03h0oooo0P00003J0?ooo`008P3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0e`3o
ool00240oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=H0oooo000O0?ooo`800000LP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0=D0oooo000N0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`3D0?ooo`007@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0d`3oool001`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo0=80oooo000;0?ooo`L000002@3oool00`000000oooo0?ooo`0Y
0?ooo`@000001P3oool2000000H0oooo1000000f0?ooo`030000003oool0oooo03H0oooo10000006
0?ooo`800000103oool00`000000oooo00000003000003H0oooo1`00000d0?ooo`L00000103oool2
000000H0oooo1000000f0?ooo`H000002P3oool000h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`050?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`003P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo0P00000f0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`04
0000003oool0oooo000003P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool00080oooo1P0000060?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool6000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
0000>03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0:0?ooo`003P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000
=P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool5000003P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`@00000
>P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool000`0oooo0`0000050?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`<00000>03oool3
000000l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool40000
00h0oooo1@00000e0?ooo`030000003oool0oooo03H0oooo1000000>0?ooo`D000000P3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03@3oool50000
03H0oooo1000000;0?ooo`004P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0a`3oool00140oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0<H0oooo000@0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`350?ooo`003`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0a03oool000h0oooo00<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0<<0oooo000=0?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`320?ooo`00
303oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
`@3oool000/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0<00oooo003o00000;0000000@3oool000X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00T0oooo002C0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0_03oool009<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2k0?ooo`00T`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0;X0oooo002C0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0^P3oool009<0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`2i0?ooo`00T`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0;P0
oooo002C0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0]`3oool009<0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`2f0?ooo`00T`3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo0;D0oooo002C0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0]@3oool009<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2d0?ooo`00
T`3oool2000006D0oooo00<000000?ooo`3oool0/`3oool009<0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`2b0?ooo`00T`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo0;40oooo002C0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0/03oool009<0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2`0?ooo`00T`3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo0:l0oooo002C0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0[P3oool009<0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2]
0?ooo`00T`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0:d0oooo002C0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0[03oool009<0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`2[0?ooo`00T`3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo0:X0oooo002C0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0Z@3oool0
09<0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2Y0?ooo`00T`3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0:P0oooo002C0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0Y`3oool009<0oooo0P00001b0?ooo`030000003oool0oooo0:H0oooo002C
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0YP3oool009<0oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0?ooo`2U0?ooo`00T`3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0:@0oooo002C0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
X`3oool009<0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2S0?ooo`00T`3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0:80oooo002C0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0X@3oool009<0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2P0?ooo`00T`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0:00oooo
002C0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0W`3oool009<0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`2N0?ooo`00T`3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo09h0oooo002C0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0W@3oool009<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`2L0?ooo`00T`3o
ool2000007`0oooo00<000000?ooo`3oool0W03oool009<0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`2K0?ooo`00T`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
09X0oooo002C0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0VP3oool009<0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`2I0?ooo`00T`3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo09P0oooo002C0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0V03oool009<0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2G0?oo
o`00T`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo09H0oooo002C0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool0UP3oool009<0oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`2E0?ooo`00Q@3oool6000000P0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`2D0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`2D0?ooo`00QP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0T`3oool008L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0980oooo
00280?ooo`030000003oool0oooo00P0oooo0`0000250?ooo`030000003oool0oooo0980oooo0029
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`2A
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`2@0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`2@0?ooo`00
QP3oool4000000T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2?0?ooo`00T`3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo08h0oooo002C0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0SP3oool009<0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`2=0?ooo`00T`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08d0
oooo002C0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0S03oool009<0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2;0?ooo`00T`3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo08/0oooo002C0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0RP3oool009<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2:0?ooo`00
T`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08T0oooo002C0?ooo`800000T03o
ool00`000000oooo0?ooo`280?ooo`00T`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo08P0oooo002C0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0Q`3oool009<0
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`260?ooo`00T`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo08H0oooo002C0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0Q@3oool009<0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`25
0?ooo`00T`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo08@0oooo002C0?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0P`3oool009<0oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`230?ooo`00T`3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo0880oooo002C0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0PP3oool0
09<0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`210?ooo`00T`3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo0800oooo002C0?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0P03oool009<0oooo0P00002I0?ooo`030000003oool0oooo07l0oooo002C
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0O`3oool009<0oooo00<000000?oo
o`3oool0V@3oool00`000000oooo0?ooo`1n0?ooo`00T`3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo07d0oooo002C0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0
O@3oool009<0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`1l0?ooo`00T`3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo07`0oooo002C0?ooo`030000003oool0oooo
09`0oooo00<000000?ooo`3oool0N`3oool009<0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`1k0?ooo`00T`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo07X0oooo
002C0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0NP3oool009<0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`1i0?ooo`00T`3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo07P0oooo002C0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0N03oool009<0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1g0?ooo`00T`3o
ool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo07L0oooo002C0?ooo`800000XP3oool0
0`000000oooo0?ooo`1f0?ooo`00T`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
07H0oooo002C0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0M@3oool009<0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`1e0?ooo`00T`3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo07@0oooo002C0?ooo`030000003oool0oooo0:<0oooo00<00000
0?ooo`3oool0M03oool009<0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1c0?oo
o`00T`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0780oooo002C0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0LP3oool009<0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`1a0?ooo`00T`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo0740oooo00270?ooo`@00000203oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
0700oooo00290?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`1`0?ooo`00R@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool0K`3oool008D0oooo1P0000080?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool0K`3oool008H0oooo00@000000?ooo`3oool000002@3oool300000:T0oooo00<0
00000?ooo`3oool0KP3oool008H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo06h0oooo00270?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`1]0?ooo`00Q`3oool00`000000oooo000000090?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0K@3oool008P0oooo0P0000090?ooo`03
0000003oool0oooo0:/0oooo00<000000?ooo`3oool0K03oool009<0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`1/0?ooo`00T`3oool00`000000oooo0?ooo`2/0?ooo`030000003o
ool0oooo06/0oooo002C0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0J`3oool0
09<0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`1Z0?ooo`00T`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo06X0oooo002C0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool0J@3oool009<0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`1Y0?ooo`00T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo06P0oooo002C0?oo
o`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0J03oool009<0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`1W0?ooo`00T`3oool200000;40oooo00<000000?ooo`3oool0
I`3oool009<0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`1V0?ooo`00T`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo06H0oooo002C0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool0I@3oool009<0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`1U0?ooo`00T`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo06@0oooo
002C0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0I03oool009<0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`1S0?ooo`00T`3oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo06<0oooo002C0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool0HP3oool009<0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`1R0?ooo`00T`3o
ool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo0640oooo002C0?ooo`030000003oool0
oooo0;H0oooo00<000000?ooo`3oool0H@3oool009<0oooo00<000000?ooo`3oool0]`3oool00`00
0000oooo0?ooo`1P0?ooo`00T`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo0600
oooo002C0?ooo`800000^@3oool00`000000oooo0?ooo`1O0?ooo`00T`3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo05l0oooo002C0?ooo`030000003oool0oooo0;T0oooo00<00000
0?ooo`3oool0GP3oool009<0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`1N0?oo
o`00T`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo05d0oooo002C0?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0G@3oool009<0oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`1M0?ooo`00T`3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo05`0oooo002C0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0G03oool009<0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`1K0?ooo`00T`3oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo05/0oooo002C0?ooo`030000003oool0oooo0;d0oooo00<0
00000?ooo`3oool0FP3oool009<0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`1J
0?ooo`00T`3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo05T0oooo002C0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0F@3oool009<0oooo0P0000300?ooo`030000
003oool0oooo05P0oooo002C0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0F03o
ool009<0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`1G0?ooo`00T`3oool00`00
0000oooo0?ooo`300?ooo`030000003oool0oooo05L0oooo002C0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool0EP3oool009<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`1F0?ooo`00T`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo05D0oooo002C
0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0E@3oool009<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`1D0?ooo`00T`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo05@0oooo002C0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
E03oool009<0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`1C0?ooo`00Q`3oool4
000000P0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`1C0?ooo`00QP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`1B0?ooo`00QP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`1B0?ooo`00QP3oool2000000<0oooo
00<000000?ooo`3oool01@3oool300000<H0oooo00<000000?ooo`3oool0D@3oool008H0oooo00<0
00000?ooo`0000000P0000080?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0D@3o
ool008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo0500oooo00270?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`1@0?ooo`00R03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool0C`3oool008T0oooo0`0000070?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0C`3oool009<0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`1>0?ooo`00T`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo04h0oooo002C0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0C@3oool009<0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`1=0?ooo`00T`3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo04`0oooo002C0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0C03o
ool009<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`1<0?ooo`00T`3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo04/0oooo002C0?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool0B`3oool00001\
\>"],
  ImageRangeCache->{{{108, 395}, {757, 580.063}} -> {-2.26722, 26.4073, \
0.0110028, 0.049476}}]
}, Open  ]],

Cell["\<\
(Angen\[ADoubleDot]herte) Transformation in eine Funktion mit Wertbereich \
[0;1]:\
\>", "Text"],

Cell[BoxData[
    \(\(fnorm = NormalizeFunction[f, {\(-1\), 2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(fnorm[x]\), "\[IndentingNewLine]", 
    \(\(Plot[fnorm[x], {x, \(-1\), 2}, PlotRange \[Rule] All];\)\)}], "Input"],

Cell[BoxData[
    \(\(2500000000\ \((208333333\/2500000000 + x + 3\ \
x\^2)\)\)\/35208333333\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.014715 0.588604 [
[.02381 .00221 -6 -9 ]
[.02381 .00221 6 0 ]
[.18254 .00221 -12 -9 ]
[.18254 .00221 12 0 ]
[.5 .00221 -9 -9 ]
[.5 .00221 9 0 ]
[.65873 .00221 -3 -9 ]
[.65873 .00221 3 0 ]
[.81746 .00221 -9 -9 ]
[.81746 .00221 9 0 ]
[.97619 .00221 -3 -9 ]
[.97619 .00221 3 0 ]
[.32877 .13244 -18 -4.5 ]
[.32877 .13244 0 4.5 ]
[.32877 .25016 -18 -4.5 ]
[.32877 .25016 0 4.5 ]
[.32877 .36788 -18 -4.5 ]
[.32877 .36788 0 4.5 ]
[.32877 .4856 -18 -4.5 ]
[.32877 .4856 0 4.5 ]
[.32877 .60332 -6 -4.5 ]
[.32877 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01471 m
.02381 .02096 L
s
[(-1)] .02381 .00221 0 1 Mshowa
.18254 .01471 m
.18254 .02096 L
s
[(-0.5)] .18254 .00221 0 1 Mshowa
.5 .01471 m
.5 .02096 L
s
[(0.5)] .5 .00221 0 1 Mshowa
.65873 .01471 m
.65873 .02096 L
s
[(1)] .65873 .00221 0 1 Mshowa
.81746 .01471 m
.81746 .02096 L
s
[(1.5)] .81746 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(2)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.05556 .01471 m
.05556 .01846 L
s
.0873 .01471 m
.0873 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.15079 .01471 m
.15079 .01846 L
s
.21429 .01471 m
.21429 .01846 L
s
.24603 .01471 m
.24603 .01846 L
s
.27778 .01471 m
.27778 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.37302 .01471 m
.37302 .01846 L
s
.40476 .01471 m
.40476 .01846 L
s
.43651 .01471 m
.43651 .01846 L
s
.46825 .01471 m
.46825 .01846 L
s
.53175 .01471 m
.53175 .01846 L
s
.56349 .01471 m
.56349 .01846 L
s
.59524 .01471 m
.59524 .01846 L
s
.62698 .01471 m
.62698 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.72222 .01471 m
.72222 .01846 L
s
.75397 .01471 m
.75397 .01846 L
s
.78571 .01471 m
.78571 .01846 L
s
.84921 .01471 m
.84921 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.9127 .01471 m
.9127 .01846 L
s
.94444 .01471 m
.94444 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.34127 .13244 m
.34752 .13244 L
s
[(0.2)] .32877 .13244 1 0 Mshowa
.34127 .25016 m
.34752 .25016 L
s
[(0.4)] .32877 .25016 1 0 Mshowa
.34127 .36788 m
.34752 .36788 L
s
[(0.6)] .32877 .36788 1 0 Mshowa
.34127 .4856 m
.34752 .4856 L
s
[(0.8)] .32877 .4856 1 0 Mshowa
.34127 .60332 m
.34752 .60332 L
s
[(1)] .32877 .60332 1 0 Mshowa
.125 Mabswid
.34127 .04415 m
.34502 .04415 L
s
.34127 .07358 m
.34502 .07358 L
s
.34127 .10301 m
.34502 .10301 L
s
.34127 .16187 m
.34502 .16187 L
s
.34127 .1913 m
.34502 .1913 L
s
.34127 .22073 m
.34502 .22073 L
s
.34127 .27959 m
.34502 .27959 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33845 m
.34502 .33845 L
s
.34127 .39731 m
.34502 .39731 L
s
.34127 .42674 m
.34502 .42674 L
s
.34127 .45617 m
.34502 .45617 L
s
.34127 .51503 m
.34502 .51503 L
s
.34127 .54446 m
.34502 .54446 L
s
.34127 .57389 m
.34502 .57389 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
.5 Mabswid
.02381 .10179 m
.06244 .07821 L
.10458 .05674 L
.14415 .04059 L
.18221 .02873 L
.20178 .02404 L
.22272 .02008 L
.23293 .01854 L
.24402 .01716 L
.25449 .01614 L
.26416 .01544 L
.26882 .01519 L
.27383 .01498 L
.27626 .0149 L
.27856 .01483 L
.28063 .01479 L
.28289 .01475 L
.28429 .01474 L
.2856 .01472 L
.28679 .01472 L
.28806 .01472 L
.28873 .01472 L
.28946 .01472 L
.29023 .01472 L
.29094 .01472 L
.29222 .01473 L
.29358 .01475 L
.29486 .01477 L
.29625 .01479 L
.29878 .01485 L
.30351 .015 L
.30836 .01521 L
.31291 .01546 L
.32329 .01623 L
.3334 .01724 L
.3443 .01861 L
.36434 .0219 L
.38544 .02644 L
.42354 .03745 L
.4641 .05314 L
.50315 .07211 L
.54465 .09643 L
.58463 .12392 L
.6231 .15412 L
.66401 .19028 L
.70342 .22904 L
.7413 .26996 L
.78164 .31745 L
.82047 .36697 L
.86175 .42374 L
Mistroke
.90151 .48244 L
.93975 .54261 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`005@3oool700000380oooo100000060?ooo`8000001P3oool4000006P0oooo100000060?oo
o`8000001P3oool400000380oooo1`00000a0?ooo`L00000103oool2000000H0oooo1000000c0?oo
o`H00000503oool001P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo000H0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool05P3oool001P0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0E0?ooo`00303oool6000000H0oooo00<000000?ooo`3oool0:@3oool6
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0503oool001P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000001W0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000003D0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0=0?ooo`@00000=`3oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool001H0oooo
0`00000d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0d0?ooo`<00000=@3oool3000000l0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo000H0?ooo`030000003oool0oooo03<0oooo1000
000>0?ooo`D00000I`3oool4000000h0oooo1@00000d0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool03@3oool5000003<0oooo1000000E0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00UP3oool00`000000oooo0?ooo`3o0?oooaP0oooo002F0?ooo`030000003oool0oooo0?l0oooo
603oool009H0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00UP3oool00`000000oooo0?ooo`3o
0?oooaP0oooo002F0?ooo`030000003oool0oooo0?l0oooo603oool009H0oooo00<000000?ooo`3o
ool0o`3ooolH0?ooo`002`3ooooo000009X00000303oool001@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203o
ool<000000<0oooo00<000000?ooo`3oool02P3oool<000000030?ooo`000000oooo00/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo00000008
00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo1`0000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool0
01@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`080?ooo`@00000<P3oool00`00
0000oooo0?ooo`030?ooo`H00000=@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`00G03oool4000003H0
oooo00<000000?ooo`3oool02@3oool400000?l0oooo2`3oool005P0oooo1000000j0?ooo`030000
003oool0oooo00d0oooo1000003o0?ooo`L0oooo001D0?ooo`@00000?P3oool00`000000oooo0?oo
o`0A0?ooo`<00000o`3oool40?ooo`00D@3oool300000480oooo00<000000?ooo`3oool0503oool3
00000?l0oooo0@3oool004h0oooo0`0000150?ooo`030000003oool0oooo01L0oooo1000003l0?oo
o`00B`3oool3000004P0oooo00<000000?ooo`3oool06`3oool300000?T0oooo00180?ooo`<00000
B`3oool00`000000oooo0?ooo`0N0?ooo`<00000mP3oool004D0oooo0`00001>0?ooo`030000003o
ool0oooo0240oooo0P00003d0?ooo`00@P3oool300000540oooo0`00000S0?ooo`<00000l@3oool0
03l0oooo0`00001D0?ooo`030000003oool0oooo02H0oooo0`00003^0?ooo`00?@3oool2000005L0
oooo00<000000?ooo`3oool0:@3oool200000>`0oooo000j0?ooo`<00000F@3oool00`000000oooo
0?ooo`0[0?ooo`<00000j@3oool003L0oooo0`00001L0?ooo`030000003oool0oooo02h0oooo0P00
003W0?ooo`00=@3oool2000005l0oooo00<000000?ooo`3oool0<03oool200000>D0oooo000c0?oo
o`800000H@3oool00`000000oooo0?ooo`0b0?ooo`800000h`3oool00340oooo0P00001S0?ooo`03
0000003oool0oooo03@0oooo0P00003Q0?ooo`00;`3oool2000006D0oooo00<000000?ooo`3oool0
=P3oool200000=l0oooo000]0?ooo`800000I`3oool00`000000oooo0?ooo`0h0?ooo`800000g@3o
ool002/0oooo0P00001Y0?ooo`030000003oool0oooo03X0oooo0P00003K0?ooo`00:@3oool20000
06/0oooo00<000000?ooo`3oool0?03oool200000=T0oooo000W0?ooo`800000K@3oool3000003h0
oooo0P00003G0?ooo`009@3oool2000006l0oooo00<000000?ooo`3oool0@03oool200000=D0oooo
000T0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0@P3oool200000=<0oooo000R
0?ooo`800000LP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0=00oooo000Q0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0A@3oool200000=00oooo000O0?ooo`80
0000M@3oool00`000000oooo0?ooo`170?ooo`800000cP3oool001d0oooo0P00001g0?ooo`030000
003oool0oooo04T0oooo0P00003<0?ooo`00703oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0b@3oool001X0oooo0P00001j0?ooo`030000003oool0
oooo04`0oooo0P0000390?ooo`006@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
04h0oooo0P0000370?ooo`005`3oool2000007d0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`340?ooo`005@3oool2000007l0oooo00<000000?ooo`3oool0D@3oool200000<@0oooo
000D0?ooo`030000003oool0oooo07l0oooo0`00001C0?ooo`030000003oool0oooo0<40oooo002F
0?ooo`030000003oool0oooo05@0oooo0P0000310?ooo`00UP3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0;h0oooo002F0?ooo`030000003oool0oooo05L0oooo0P00002n0?ooo`00
UP3oool00`000000oooo0?ooo`1I0?ooo`800000_03oool009H0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`2i0?ooo`00UP3oool00`000000oooo0?ooo`1L0?ooo`800000^@3oool0
09H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2f0?ooo`00UP3oool00`000000
oooo0?ooo`1O0?ooo`800000]P3oool007P0oooo100000060?ooo`8000001@3oool6000000L0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`2c0?ooo`00M`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0;80oooo001g
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo06<0oooo0P00002b0?ooo`00M`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool4000006@0oooo00<000000?oo
o`3oool0[`3oool007L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2^0?ooo`00
M`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0:d0oooo001g0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0J03oool200000:d0oooo001g0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2Z0?ooo`00N03oool40000
00h0oooo100000080?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0Z@3oool009H0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2X0?ooo`00UP3oool00`000000oooo
0?ooo`1]0?ooo`800000Z03oool009H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`2U0?ooo`00UP3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0:@0oooo002F0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0X`3oool009H0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`2R0?ooo`00UP3oool3000007<0oooo00<000000?ooo`3oool0
X@3oool009H0oooo00<000000?ooo`3oool0M03oool200000:40oooo002F0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0WP3oool009H0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`2M0?ooo`00UP3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo09`0
oooo002F0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0V`3oool009H0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`2J0?ooo`00UP3oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo09T0oooo002F0?ooo`030000003oool0oooo07`0oooo0P00002I0?oo
o`00UP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo09H0oooo002F0?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0U@3oool009H0oooo00<000000?ooo`3oool0P03o
ool00`000000oooo0?ooo`2D0?ooo`00UP3oool300000840oooo00<000000?ooo`3oool0T`3oool0
09H0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`2B0?ooo`00UP3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo0940oooo002F0?ooo`030000003oool0oooo08@0oooo
00<000000?ooo`3oool0T03oool009H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`2?0?ooo`00UP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08h0oooo002F0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool0S@3oool009H0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`2<0?ooo`00UP3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo08/0oooo002F0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0RP3o
ool009H0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`290?ooo`00UP3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo08P0oooo002F0?ooo`<00000S@3oool00`000000
oooo0?ooo`270?ooo`00UP3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08H0oooo
002F0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0Q@3oool009H0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`240?ooo`00UP3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo08<0oooo002F0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0PP3oool009H0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`210?ooo`00UP3o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0800oooo002F0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0O`3oool007P0oooo100000060?ooo`8000001`3oool40000
00L0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1n0?ooo`00M`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`1m0?ooo`00M`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo07`0oooo001g0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool6000000L0oooo1000002H0?ooo`030000003oool0oooo07/0oooo001g
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0N`3oool007L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`1j0?ooo`00M`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo07T0oooo001g0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo000000080?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0N03oool007P0oooo1000000@0?ooo`800000203oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo07L0oooo002F0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
MP3oool009H0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`1e0?ooo`00UP3oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo07@0oooo002F0?ooo`030000003oool0oooo
0:40oooo00<000000?ooo`3oool0L`3oool009H0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`1b0?ooo`00UP3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0740oooo
002F0?ooo`<00000Y03oool00`000000oooo0?ooo`1`0?ooo`00UP3oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo0700oooo002F0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool0K`3oool009H0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1^0?ooo`00
UP3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo06d0oooo002F0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0K03oool009H0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`1[0?ooo`00UP3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
06/0oooo002F0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0JP3oool009H0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1Y0?ooo`00UP3oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo06P0oooo002F0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool0I`3oool009H0oooo0`00002^0?ooo`030000003oool0oooo06H0oooo002F0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0IP3oool009H0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`1U0?ooo`00UP3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo06@0oooo002F0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0H`3oool0
09H0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`1R0?ooo`00UP3oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo0640oooo002F0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool0H@3oool009H0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`1P0?ooo`00UP3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo05l0oooo002F0?oo
o`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0GP3oool009H0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`1M0?ooo`00UP3oool00`000000oooo0?ooo`2g0?ooo`030000
003oool0oooo05d0oooo002F0?ooo`<00000^03oool00`000000oooo0?ooo`1L0?ooo`00UP3oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo05/0oooo002F0?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0FP3oool009H0oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`1I0?ooo`00UP3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo05T0oooo
002F0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0F03oool009H0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`1G0?ooo`00UP3oool00`000000oooo0?ooo`2n0?oo
o`030000003oool0oooo05H0oooo001h0?ooo`@000001P3oool2000000L0oooo100000070?ooo`03
0000003oool0oooo0;l0oooo00<000000?ooo`3oool0E@3oool007L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1E0?ooo`00M`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0E03o
ool007L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0D`3oool0
07L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000
008000001`3oool400000<40oooo00<000000?ooo`3oool0DP3oool007L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0`P3oool00`000000oooo0?ooo`1B0?ooo`00M`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0540oooo001g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0D03o
ool007P0oooo1000000A0?ooo`<000001P3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo04l0oooo002F0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0C`3oool009H0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`1>0?ooo`00UP3oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo04d0oooo002F0?ooo`030000003oool0oooo0<P0oooo00<0
00000?ooo`3oool0C03oool009H0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`1<
0?ooo`00UP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo04/0oooo002F0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool0BP3oool009H0oooo0`00003;0?ooo`030000
003oool0oooo04T0oooo002F0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0B@3o
ool009H0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`180?ooo`00UP3oool00`00
0000oooo0?ooo`3=0?ooo`030000003oool0oooo04L0oooo002F0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0AP3oool009H0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`160?ooo`00UP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo04D0oooo002F
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0A03oool009H0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`130?ooo`00UP3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo04<0oooo002F0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
@P3oool009H0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`110?ooo`00UP3oool3
00000=<0oooo00<000000?ooo`3oool0@@3oool009H0oooo00<000000?ooo`3oool0e03oool00`00
0000oooo0?ooo`100?ooo`00UP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo03l0
oooo002F0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0?`3oool009H0oooo00<0
00000?ooo`3oool0eP3oool00`000000oooo0?ooo`0n0?ooo`00UP3oool00`000000oooo0?ooo`3G
0?ooo`030000003oool0oooo03d0oooo002F0?ooo`030000003oool0oooo0=L0oooo00<000000?oo
o`3oool0?@3oool009H0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0l0?ooo`00
UP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo03/0oooo002F0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`3oool0>`3oool009H0oooo00<000000?ooo`3oool0fP3oool0
0`000000oooo0?ooo`0j0?ooo`00UP3oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo
03T0oooo002F0?ooo`<00000f`3oool00`000000oooo0?ooo`0i0?ooo`00UP3oool00`000000oooo
0?ooo`3L0?ooo`030000003oool0oooo03P0oooo002F0?ooo`030000003oool0oooo0=d0oooo00<0
00000?ooo`3oool0=`3oool009H0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`0g
0?ooo`00UP3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo03H0oooo002F0?ooo`03
0000003oool0oooo0=l0oooo00<000000?ooo`3oool0=@3oool009H0oooo00<000000?ooo`3oool0
g`3oool00`000000oooo0?ooo`0e0?ooo`00UP3oool00`000000oooo0?ooo`3P0?ooo`030000003o
ool0oooo03@0oooo001h0?ooo`@000001P3oool2000000H0oooo100000080?ooo`030000003oool0
oooo0>40oooo00<000000?ooo`3oool0<`3oool007L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`0c0?ooo`00M`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool0<P3oool007L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3S0?ooo`030000003oool0oooo0340oooo
001g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool4000000P0oooo1000
003R0?ooo`030000003oool0oooo0340oooo001g0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0i03oool00`000000oooo0?ooo`0`0?ooo`00M`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0;`3oool007L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo02l0oooo001h0?ooo`@00000
3P3oool4000000P0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0^0?ooo`00UP3o
ool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo02h0oooo002F0?ooo`030000003oool0
oooo0>L0oooo00<000000?ooo`3oool0;@3oool009H0oooo00<000000?ooo`3oool0j03oool00`00
0000oooo0?ooo`0/0?ooo`00UP3oool00`000000oooo0?ooo`3X0?ooo`030000003oool0oooo02`0
oooo002F0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0:`3oool009H0oooo00<0
00000?ooo`3oool0jP3oool00`000000oooo0?ooo`0Z0?ooo`00UP3oool00`000000oooo0?ooo`3Z
0?ooo`030000003oool0oooo02X0oooo002F0?ooo`<00000j`3oool00`000000oooo0?ooo`0Y0?oo
o`00UP3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo02P0oooo002F0?ooo`030000
003oool0oooo0>`0oooo00<000000?ooo`3oool0:03oool009H0oooo00<000000?ooo`3oool0k@3o
ool00`000000oooo0?ooo`0W0?ooo`00UP3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0
oooo02H0oooo002F0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool09P3oool009H0
oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0U0?ooo`00UP3oool00`000000oooo
0?ooo`3_0?ooo`030000003oool0oooo02D0oooo002F0?ooo`030000003oool0oooo0?00oooo00<0
00000?ooo`3oool0903oool009H0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0S
0?ooo`00UP3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo02<0oooo002F0?ooo`03
0000003oool0oooo0?80oooo00<000000?ooo`3oool08P3oool009H0oooo0`00003c0?ooo`030000
003oool0oooo0240oooo002F0?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool08@3o
ool009H0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0P0?ooo`00UP3oool00`00
0000oooo0?ooo`3d0?ooo`030000003oool0oooo0200oooo002F0?ooo`030000003oool0oooo0?D0
oooo00<000000?ooo`3oool07`3oool009H0oooo00<000000?ooo`3oool0mP3oool00`000000oooo
0?ooo`0N0?ooo`00UP3oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo01h0oooo002F
0?ooo`030000003oool0oooo0?L0oooo00<000000?ooo`3oool07@3oool009H0oooo00<000000?oo
o`3oool0m`3oool00`000000oooo0?ooo`0M0?ooo`00UP3oool00`000000oooo0?ooo`3h0?ooo`03
0000003oool0oooo01`0oooo002F0?ooo`030000003oool0oooo0?T0oooo00<000000?ooo`3oool0
6`3oool009H0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0K0?ooo`00UP3oool3
00000?X0oooo00<000000?ooo`3oool06P3oool009H0oooo00<000000?ooo`3oool0nP3oool00`00
0000oooo0?ooo`0J0?ooo`00UP3oool00`000000oooo0?ooo`3k0?ooo`030000003oool0oooo01T0
oooo002F0?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0603oool009H0oooo00<0
00000?ooo`3oool0o03oool00`000000oooo0?ooo`0H0?ooo`00UP3oool00`000000oooo0?ooo`3m
0?ooo`030000003oool0oooo01L0oooo002F0?ooo`030000003oool0oooo0?d0oooo00<000000?oo
o`3oool05`3oool009H0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?ooo`0F0?ooo`00
R@3oool7000000H0oooo00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`0E0?ooo`00S03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool05@3o
ool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<00000
0?ooo`3oool0503oool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
o`40oooo00<000000?ooo`3oool0503oool008`0oooo00<000000?ooo`3oool01`3oool400000?l0
oooo0@3oool00`000000oooo0?ooo`0C0?ooo`00S03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0?l0oooo603oool008`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`3o0?oooaP0oooo002:0?ooo`<000002@3oool00`000000oooo0?ooo`3o0?oooaP0oooo002<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00UP3oool00`000000
oooo0?ooo`3o0?oooaP0oooo002F0?ooo`030000003oool0oooo0?l0oooo603oool00001\
\>"],
  ImageRangeCache->{{{108, 395}, {412.813, 235.875}} -> {-2.41377, 1.3964, \
0.0115856, 0.00624861}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Nutzenfunktionen", "Section"],

Cell[CellGroupData[{

Cell["Erzeugung diverser Funktionstypen", "Subsection"],

Cell["\<\
Erzeugung einer linearen Nutzenfunktion, die \[UDoubleDot]ber dem Intervall \
[5;10] normiert ist:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LinUtility[2, \(-5\), Normalize \[Rule] {5, 10}]\)[x]\)], "Input"],

Cell[BoxData[
    \(\(10 - x\)\/5\)], "Output"]
}, Open  ]],

Cell["\<\
Erzeugung einet quadratischen Nutzenfunktion, die \[UDoubleDot]ber dem \
Intervall [-1;4] normiert ist:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(QuadUtility[2, \(-5\), 3, Normalize \[Rule] {\(-1\), 4}]\)[
      x]\)], "Input"],

Cell[BoxData[
    \(12\/361\ \((25\/12 - 5\ x + 3\ x\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[%, {x, \(-2\), 5}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.136054 0.0147151 0.339978 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.15986 .00222 -6 -9 ]
[.15986 .00222 6 0 ]
[.43197 .00222 -3 -9 ]
[.43197 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.28342 .09971 -24 -4.5 ]
[.28342 .09971 0 4.5 ]
[.28342 .1847 -18 -4.5 ]
[.28342 .1847 0 4.5 ]
[.28342 .2697 -24 -4.5 ]
[.28342 .2697 0 4.5 ]
[.28342 .35469 -6 -4.5 ]
[.28342 .35469 0 4.5 ]
[.28342 .43969 -24 -4.5 ]
[.28342 .43969 0 4.5 ]
[.28342 .52468 -18 -4.5 ]
[.28342 .52468 0 4.5 ]
[.28342 .60968 -24 -4.5 ]
[.28342 .60968 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.15986 .01472 m
.15986 .02097 L
s
[(-1)] .15986 .00222 0 1 Mshowa
.43197 .01472 m
.43197 .02097 L
s
[(1)] .43197 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(2)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(3)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(4)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.29592 .09971 m
.30217 .09971 L
s
[(0.25)] .28342 .09971 1 0 Mshowa
.29592 .1847 m
.30217 .1847 L
s
[(0.5)] .28342 .1847 1 0 Mshowa
.29592 .2697 m
.30217 .2697 L
s
[(0.75)] .28342 .2697 1 0 Mshowa
.29592 .35469 m
.30217 .35469 L
s
[(1)] .28342 .35469 1 0 Mshowa
.29592 .43969 m
.30217 .43969 L
s
[(1.25)] .28342 .43969 1 0 Mshowa
.29592 .52468 m
.30217 .52468 L
s
[(1.5)] .28342 .52468 1 0 Mshowa
.29592 .60968 m
.30217 .60968 L
s
[(1.75)] .28342 .60968 1 0 Mshowa
.125 Mabswid
.29592 .03171 m
.29967 .03171 L
s
.29592 .04871 m
.29967 .04871 L
s
.29592 .06571 m
.29967 .06571 L
s
.29592 .08271 m
.29967 .08271 L
s
.29592 .11671 m
.29967 .11671 L
s
.29592 .13371 m
.29967 .13371 L
s
.29592 .15071 m
.29967 .15071 L
s
.29592 .16771 m
.29967 .16771 L
s
.29592 .2017 m
.29967 .2017 L
s
.29592 .2187 m
.29967 .2187 L
s
.29592 .2357 m
.29967 .2357 L
s
.29592 .2527 m
.29967 .2527 L
s
.29592 .2867 m
.29967 .2867 L
s
.29592 .3037 m
.29967 .3037 L
s
.29592 .32069 m
.29967 .32069 L
s
.29592 .33769 m
.29967 .33769 L
s
.29592 .37169 m
.29967 .37169 L
s
.29592 .38869 m
.29967 .38869 L
s
.29592 .40569 m
.29967 .40569 L
s
.29592 .42269 m
.29967 .42269 L
s
.29592 .45669 m
.29967 .45669 L
s
.29592 .47368 m
.29967 .47368 L
s
.29592 .49068 m
.29967 .49068 L
s
.29592 .50768 m
.29967 .50768 L
s
.29592 .54168 m
.29967 .54168 L
s
.29592 .55868 m
.29967 .55868 L
s
.29592 .57568 m
.29967 .57568 L
s
.29592 .59268 m
.29967 .59268 L
s
.25 Mabswid
.29592 0 m
.29592 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28689 m
.06244 .23506 L
.10458 .18478 L
.14415 .14348 L
.18221 .10917 L
.22272 .07848 L
.26171 .05461 L
.28158 .04459 L
.30316 .03535 L
.32216 .02862 L
.34309 .02274 L
.36292 .01865 L
.37378 .01703 L
.38395 .01589 L
.38891 .01548 L
.39154 .01529 L
.39433 .01513 L
.39702 .01499 L
.39945 .01489 L
.40189 .01482 L
.40299 .01479 L
.4042 .01476 L
.40536 .01474 L
.40645 .01473 L
.4076 .01472 L
.40883 .01472 L
.40998 .01472 L
.41106 .01472 L
.41204 .01473 L
.4131 .01474 L
.41425 .01476 L
.41552 .01479 L
.4181 .01486 L
.42048 .01494 L
.42272 .01505 L
.42742 .01532 L
.43256 .01571 L
.44291 .01678 L
.45249 .01813 L
.46141 .01969 L
.48187 .02436 L
.50046 .02994 L
.54044 .04621 L
.5789 .0674 L
.61982 .09589 L
.65923 .12912 L
.69711 .16644 L
.73745 .21195 L
.77628 .26138 L
.81755 .31999 L
Mistroke
.85731 .38234 L
.89556 .44779 L
.93626 .52332 L
.97544 .60176 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`005`3oool600000340oooo1`00001S0?ooo`L00000<03oool600000380oooo1000000d0?oo
o`@00000<P3oool4000001L0oooo000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0503oool001P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0503oool001T0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0_0?ooo`H00000=P3oool00`000000oooo0?ooo`0D0?ooo`003P3oool6
000000H0oooo00<000000?ooo`3oool0:03oool6000000H0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo0P00000c0?ooo`040000003oool0
oooo000003L0oooo00<000000?ooo`3oool0503oool001/0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0`0?ooo`040000003oool0oooo000003<0oooo1000000G0?ooo`005`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0000003<0oooo00<000000?ooo`3oool0603oool0
01L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`<00000I`3oool30000
03<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0<@3oool00`000000oooo0000000c0?ooo`030000003oool0oooo
01P0oooo000H0?ooo`@00000=@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0380
oooo1000000c0?ooo`@00000=@3oool2000003<0oooo1@00000F0?ooo`00o`3ooona0?ooo`00o`3o
oona0?ooo`00Q03oool00`000000oooo0?ooo`3o0?ooobX0oooo00240?ooo`030000003oool0oooo
0?l0oooo:P3oool008@0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00Q03oool00`000000oooo
0?ooo`3o0?ooobX0oooo00240?ooo`030000003oool0oooo0?l0oooo:P3oool008@0oooo00<00000
0?ooo`3oool0o`3ooolZ0?ooo`003@3ooooo000009H000003P3oool001H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01P3oool7000000H0oooo00<000000?ooo`3oool0203oool7000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0600000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
200000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0@0?ooo`H000007P3oool00`000000oooo0?oo
o`0<0?ooo`@000009@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`00Q03oool00`000000oooo0?ooo`0=
0?ooo`<00000=`3oool400000=h0oooo00240?ooo`030000003oool0oooo00X0oooo0`00000n0?oo
o`@00000fP3oool008@0oooo00<000000?ooo`3oool01`3oool3000004D0oooo0`00003G0?ooo`00
Q03oool3000000D0oooo0P00001;0?ooo`800000e@3oool008@0oooo00<000000?ooo`3oool00P3o
ool3000004l0oooo0P00003C0?ooo`00Q03oool00`000000oooo00000002000005@0oooo0P00003A
0?ooo`00Q03oool2000005T0oooo0`00003>0?ooo`00P@3oool4000005d0oooo0P00003<0?ooo`00
O`3oool2000000<0oooo00<000000?ooo`3oool0G@3oool200000<X0oooo001m0?ooo`8000001@3o
ool00`000000oooo0?ooo`1O0?ooo`800000b03oool007/0oooo0P0000070?ooo`<00000H@3oool2
00000<H0oooo001i0?ooo`8000002@3oool00`000000oooo0?ooo`1S0?ooo`800000a03oool007L0
oooo0P00000;0?ooo`030000003oool0oooo06D0oooo0P0000320?ooo`00M@3oool2000000d0oooo
00<000000?ooo`3oool0I`3oool200000<00oooo001d0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0J@3oool200000;h0oooo001b0?ooo`800000403oool00`000000oooo0?ooo`1[
0?ooo`800000_03oool00700oooo0P00000B0?ooo`030000003oool0oooo06d0oooo0P00002j0?oo
o`00K`3oool00`000000oooo0?ooo`0B0?ooo`<00000K`3oool200000;P0oooo001]0?ooo`800000
5@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0;D0oooo001/0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0LP3oool200000;D0oooo001Z0?ooo`800000603oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0;80oooo001X0?ooo`8000006P3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo0;40oooo001W0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0MP3oool200000;40oooo001V0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2^0?ooo`00I03oool2000001h0oooo0`00
001i0?ooo`030000003oool0oooo0:d0oooo001S0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0NP3oool200000:d0oooo001R0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`2Z0?ooo`00G@3oool5000000D0oooo0P0000050?ooo`H0
0000103oool4000000P0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2Y0?ooo`00
G03oool01P000000oooo0?ooo`000000oooo000000D0oooo0P0000050?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0OP3oool200000:T0oooo001L0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2V0?ooo`00G03oool2000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`2U0?ooo`00F`3oool2000000@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo100000210?ooo`800000
Y@3oool005X0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo100000080?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0XP3o
ool005P0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0:40oooo001G0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0X03oool005H0oooo00<000000?ooo`3oool0103oool4000000h0
oooo100000050?ooo`D000001`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo09l0
oooo001E0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0R03oool2000009l0oooo
001D0?ooo`030000003oool0oooo02d0oooo0`00002:0?ooo`030000003oool0oooo09`0oooo001B
0?ooo`800000<03oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo09/0oooo001A0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2J0?oo
o`00D03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo08d0oooo0P00002J0?ooo`00
C`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
U`3oool004h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo09H0oooo001=0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`2E0?ooo`00C03oool00`000000oooo0?ooo`0e0?ooo`<00000TP3oool00`00
0000oooo0?ooo`2D0?ooo`00BP3oool2000003P0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`2C0?ooo`00B@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0TP3oool004P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0940oooo00170?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`2@0?ooo`00AP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo09L0oooo00<000000?ooo`3oool0S`3oool004D0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo08h0oooo00140?ooo`030000
003oool0oooo03d0oooo0`00002I0?ooo`030000003oool0oooo08d0oooo00130?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2<0?ooo`00@P3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0R`3oool0
0440oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
08X0oooo00100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`290?ooo`00?`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0R03oool003l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo08L0oooo000n0?ooo`030000003oool0oooo04<0oooo0`00002P
0?ooo`030000003oool0oooo08H0oooo000m0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`250?ooo`00?03oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0:80oooo00<000000?ooo`3oool0Q03oool003/0oooo00<000000?ooo`3oool0
:03oool4000000H0oooo0P0000060?ooo`@00000203oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo08<0oooo000j0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`220?ooo`00>@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0PP3oool0
03P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
0840oooo000g0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo1000002U0?ooo`030000003oool0oooo0800
oooo000f0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`@00000203oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo07l0oooo
000e0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`1n0?ooo`00=03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool0O@3oool003@0oooo00<000000?ooo`3oool0;`3oool4000000h0oooo1@0000070?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0O03oool003<0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo07/0oooo000b0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1j0?ooo`00<@3o
ool00`000000oooo0?ooo`1@0?ooo`<00000[03oool00`000000oooo0?ooo`1j0?ooo`00<03oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0N@3oool0
02l0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
07P0oooo000^0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`1g0?ooo`00;P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool0MP3oool002d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo07D0oooo000/0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`1d0?ooo`00:`3oool00`000000oooo0?ooo`1F0?oo
o`<00000/P3oool00`000000oooo0?ooo`1d0?ooo`00:P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0;<0oooo00<000000?ooo`3oool0L`3oool002T0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0780oooo000Y0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`1a0?ooo`00:03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3oool0L03oool0
02L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
0700oooo000V0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`1_0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`<00000^03oool00`000000oooo
0?ooo`1^0?ooo`00903oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0;T0oooo00<0
00000?ooo`3oool0K@3oool002@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo06`0oooo000S0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`1/0?ooo`008P3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool0J`3oool00240oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo06X0oooo000Q0?ooo`030000003o
ool0oooo0600oooo0`00002m0?ooo`030000003oool0oooo06T0oooo000P0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`1X0?ooo`007`3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0J03oool001h0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo06L0
oooo000N0?ooo`030000003oool0oooo03`0oooo100000060?ooo`800000203oool00`000000oooo
0?ooo`040?ooo`@00000203oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo06H0oooo
000M0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo06D0oooo000L
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`31
0?ooo`030000003oool0oooo06D0oooo000K0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool400000<40oooo00<000000?ooo`3oool0I03oool001/0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0H`3oool001X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool4000000P0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`1S0?ooo`006@3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`1R0?ooo`00603oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo0640oooo000H0?ooo`030000003oool0oooo
0480oooo1000000=0?ooo`H00000103oool5000000L0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`1Q0?ooo`005`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0<H0
oooo00<000000?ooo`3oool0H03oool001H0oooo00<000000?ooo`3oool0J`3oool300000<L0oooo
00<000000?ooo`3oool0G`3oool008@0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`1O0?ooo`00Q03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo05h0oooo00240?oo
o`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0G@3oool008@0oooo00<000000?ooo`3o
ool0b@3oool00`000000oooo0?ooo`1M0?ooo`00Q03oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo05`0oooo00240?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0F`3o
ool008@0oooo0`00003;0?ooo`030000003oool0oooo05/0oooo00240?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool0FP3oool008@0oooo00<000000?ooo`3oool0c@3oool00`000000
oooo0?ooo`1I0?ooo`00Q03oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo05T0oooo
00240?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0F03oool008@0oooo00<00000
0?ooo`3oool0c`3oool00`000000oooo0?ooo`1G0?ooo`00Q03oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo05L0oooo00240?ooo`<00000d03oool00`000000oooo0?ooo`1F0?ooo`00
Q03oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo05D0oooo00240?ooo`030000003o
ool0oooo0=40oooo00<000000?ooo`3oool0E@3oool008@0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`1D0?ooo`00Q03oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo
05<0oooo00240?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0D`3oool008@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`1B0?ooo`00Q03oool300000=@0oooo00<0
00000?ooo`3oool0DP3oool008@0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`1A
0?ooo`00Q03oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0500oooo001g0?ooo`L0
00001P3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo0500oooo001j0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0e`3oool00`000000oooo0?ooo`1?0?ooo`00NP3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0CP3o
ool007X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
oooo04h0oooo001j0?ooo`030000003oool0oooo00L0oooo1000003H0?ooo`030000003oool0oooo
04d0oooo001j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0fP3oool00`000000
oooo0?ooo`1<0?ooo`00NP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=X0oooo
00<000000?ooo`3oool0C03oool007P0oooo0`0000090?ooo`030000003oool0oooo0=/0oooo00<0
00000?ooo`3oool0B`3oool007X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3L
0?ooo`030000003oool0oooo04X0oooo00240?ooo`030000003oool0oooo0=`0oooo00<000000?oo
o`3oool0BP3oool008@0oooo00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`190?ooo`00
Q03oool300000=d0oooo00<000000?ooo`3oool0B@3oool008@0oooo00<000000?ooo`3oool0gP3o
ool00`000000oooo0?ooo`180?ooo`00Q03oool00`000000oooo0?ooo`3O0?ooo`030000003oool0
oooo04L0oooo00240?ooo`030000003oool0oooo0=l0oooo00<000000?ooo`3oool0A`3oool008@0
oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`160?ooo`00Q03oool00`000000oooo
0?ooo`3Q0?ooo`030000003oool0oooo04D0oooo00240?ooo`<00000h@3oool00`000000oooo0?oo
o`150?ooo`00Q03oool00`000000oooo0?ooo`3R0?ooo`030000003oool0oooo04@0oooo00240?oo
o`030000003oool0oooo0>80oooo00<000000?ooo`3oool0A03oool008@0oooo00<000000?ooo`3o
ool0h`3oool00`000000oooo0?ooo`130?ooo`00Q03oool00`000000oooo0?ooo`3T0?ooo`030000
003oool0oooo0480oooo00240?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool0@P3o
ool008@0oooo00<000000?ooo`3oool0i@3oool00`000000oooo0?ooo`110?ooo`00Q03oool30000
0>H0oooo00<000000?ooo`3oool0@03oool008@0oooo00<000000?ooo`3oool0iP3oool00`000000
oooo0?ooo`100?ooo`00Q03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo03l0oooo
00240?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0?`3oool008@0oooo00<00000
0?ooo`3oool0j03oool00`000000oooo0?ooo`0n0?ooo`00Q03oool00`000000oooo0?ooo`3Y0?oo
o`030000003oool0oooo03d0oooo00240?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3o
ool0?@3oool008@0oooo0`00003Z0?ooo`030000003oool0oooo03`0oooo00240?ooo`030000003o
ool0oooo0>X0oooo00<000000?ooo`3oool0?03oool008@0oooo00<000000?ooo`3oool0j`3oool0
0`000000oooo0?ooo`0k0?ooo`00Q03oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo
03X0oooo001L0?ooo`L00000103oool2000000D0oooo1P0000040?ooo`@00000203oool00`000000
oooo0?ooo`3/0?ooo`030000003oool0oooo03X0oooo001O0?ooo`030000003oool0oooo00D0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0i0?ooo`00
G`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo03P0oooo001O0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`@00000k@3o
ool00`000000oooo0?ooo`0h0?ooo`00G`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3_0?ooo`030000003oool0
oooo03L0oooo001O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool40000
00P0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0g0?ooo`00G`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?00oooo00<000000?ooo`3oool0=P3oool005d0oooo
0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0=@3oool005l0oooo00<0
00000?ooo`3oool03@3oool4000000D0oooo1@0000070?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool0=@3oool008@0oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`0d
0?ooo`00Q03oool300000?80oooo00<000000?ooo`3oool0=03oool008@0oooo00<000000?ooo`3o
ool0l`3oool00`000000oooo0?ooo`0c0?ooo`00Q03oool00`000000oooo0?ooo`3c0?ooo`030000
003oool0oooo03<0oooo00240?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool0<P3o
ool008@0oooo00<000000?ooo`3oool0m03oool00`000000oooo0?ooo`0b0?ooo`00Q03oool00`00
0000oooo0?ooo`3e0?ooo`030000003oool0oooo0340oooo00240?ooo`030000003oool0oooo0?D0
oooo00<000000?ooo`3oool0<@3oool008@0oooo0`00003f0?ooo`030000003oool0oooo0300oooo
00240?ooo`030000003oool0oooo0?H0oooo00<000000?ooo`3oool0<03oool008@0oooo00<00000
0?ooo`3oool0m`3oool00`000000oooo0?ooo`0_0?ooo`00Q03oool00`000000oooo0?ooo`3g0?oo
o`030000003oool0oooo02l0oooo00240?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3o
ool0;P3oool008@0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0^0?ooo`00Q03o
ool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo02d0oooo00240?ooo`<00000n@3oool0
0`000000oooo0?ooo`0]0?ooo`00Q03oool00`000000oooo0?ooo`3j0?ooo`030000003oool0oooo
02`0oooo00240?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool0;03oool008@0oooo
00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`0[0?ooo`00Q03oool00`000000oooo0?oo
o`3k0?ooo`030000003oool0oooo02/0oooo00240?ooo`030000003oool0oooo0?`0oooo00<00000
0?ooo`3oool0:P3oool008@0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`0Z0?oo
o`00Q03oool300000?d0oooo00<000000?ooo`3oool0:@3oool008@0oooo00<000000?ooo`3oool0
o@3oool00`000000oooo0?ooo`0Y0?ooo`00Q03oool00`000000oooo0?ooo`3n0?ooo`030000003o
ool0oooo02P0oooo001U0?ooo`L00000103oool2000000H0oooo100000080?ooo`030000003oool0
oooo0?h0oooo00<000000?ooo`3oool0:03oool006P0oooo00<000000?ooo`3oool01@3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0oooo00<000000?ooo`3oool09`3oool006P0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo00<000000?ooo`3oool09`3oool006P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`@00000o`3oool00`000000oooo
0?ooo`0V0?ooo`00J03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0o`3oool20?ooo`030000003oool0oooo02D0oooo001X0?ooo`030000003oool0
oooo00d0oooo100000080?ooo`030000003oool0oooo0?l0oooo0P3oool00`000000oooo0?ooo`0U
0?ooo`00J03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o`3oool30?ooo`030000003oool0oooo02@0oooo001V0?ooo`<000003`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?ooo`0T0?ooo`00
J03oool00`000000oooo0?ooo`0=0?ooo`D000001`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo
00<000000?ooo`3oool08`3oool008@0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003o
ool0oooo02<0oooo00240?ooo`<00000o`3oool50?ooo`030000003oool0oooo0280oooo00240?oo
o`030000003oool0oooo0?l0oooo1@3oool00`000000oooo0?ooo`0R0?ooo`00Q03oool00`000000
oooo0?ooo`3o0?ooo`H0oooo00<000000?ooo`3oool08@3oool008@0oooo00<000000?ooo`3oool0
o`3oool60?ooo`030000003oool0oooo0240oooo00240?ooo`030000003oool0oooo0?l0oooo1`3o
ool00`000000oooo0?ooo`0P0?ooo`00Q03oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<00000
0?ooo`3oool0803oool008@0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000003oool0oooo
01l0oooo00240?ooo`<00000o`3oool80?ooo`030000003oool0oooo01l0oooo00240?ooo`030000
003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`0N0?ooo`00Q03oool00`000000oooo0?oo
o`3o0?ooo`T0oooo00<000000?ooo`3oool07P3oool008@0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo01d0oooo00240?ooo`030000003oool0oooo0?l0oooo2P3oool00`00
0000oooo0?ooo`0M0?ooo`00Q03oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<000000?ooo`3o
ool0703oool008@0oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo01`0oooo
00240?ooo`<00000o`3oool<0?ooo`030000003oool0oooo01/0oooo00240?ooo`030000003oool0
oooo0?l0oooo303oool00`000000oooo0?ooo`0K0?ooo`00Q03oool00`000000oooo0?ooo`3o0?oo
o`d0oooo00<000000?ooo`3oool06P3oool008@0oooo00<000000?ooo`3oool0o`3oool=0?ooo`03
0000003oool0oooo01X0oooo00240?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo
0?ooo`0I0?ooo`00Q03oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3oool06@3o
ool008@0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000003oool0oooo01P0oooo00240?oo
o`<00000o`3oool?0?ooo`030000003oool0oooo01P0oooo00240?ooo`030000003oool0oooo0?l0
oooo403oool00`000000oooo0?ooo`0G0?ooo`00Q03oool00`000000oooo0?ooo`3o0?oooa00oooo
00<000000?ooo`3oool05`3oool005`0oooo1`0000040?ooo`800000203oool00`000000oooo0?oo
o`040?ooo`@00000203oool00`000000oooo0?ooo`3o0?oooa40oooo00<000000?ooo`3oool05P3o
ool005l0oooo00<000000?ooo`3oool01@3oool2000000P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolA
0?ooo`8000005`3oool005l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00G`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3o0?ooobX0oooo001O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`050?ooo`@00000o`3ooolY0?ooo`00G`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo100000080?ooo`030000003oool0oooo0?l0oooo:P3o
ool005l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00G@3oool3000000h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o`3ooolZ0?ooo`00G`3oool00`000000oooo0?ooo`0<0?ooo`H00000103oool500000?l0
oooo=03oool00?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{108, 395}, {373.75, 196.813}} -> {-5.37063, 2.0165, \
0.0273186, 0.0109325}}]
}, Open  ]],

Cell["\<\
Generierung und Darstellung einer \[UDoubleDot]ber [-1;2] normierten \
exponentiellen Nutzenfunktion:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ExpUtility[1, \(-2\), \(-0.5\)]\)[x]\), "\[IndentingNewLine]", 
    \(\(Plot[\(ExpUtility[1, \(-2\), \(-0.5\), 
            Normalize \[Rule] {\(-1\), 2}]\)[x], {x, \(-2\), 
          2}];\)\)}], "Input"],

Cell[BoxData[
    \(1 - 2\ \[ExponentialE]\^\(\(-0.5`\)\ x\)\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.282562 0.320757 [
[.02381 .27006 -6 -9 ]
[.02381 .27006 6 0 ]
[.2619 .27006 -6 -9 ]
[.2619 .27006 6 0 ]
[.7381 .27006 -3 -9 ]
[.7381 .27006 3 0 ]
[.97619 .27006 -3 -9 ]
[.97619 .27006 3 0 ]
[.4875 .04199 -30 -4.5 ]
[.4875 .04199 0 4.5 ]
[.4875 .12218 -24 -4.5 ]
[.4875 .12218 0 4.5 ]
[.4875 .20237 -30 -4.5 ]
[.4875 .20237 0 4.5 ]
[.4875 .36275 -24 -4.5 ]
[.4875 .36275 0 4.5 ]
[.4875 .44294 -18 -4.5 ]
[.4875 .44294 0 4.5 ]
[.4875 .52313 -24 -4.5 ]
[.4875 .52313 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .28256 m
.02381 .28881 L
s
[(-2)] .02381 .27006 0 1 Mshowa
.2619 .28256 m
.2619 .28881 L
s
[(-1)] .2619 .27006 0 1 Mshowa
.7381 .28256 m
.7381 .28881 L
s
[(1)] .7381 .27006 0 1 Mshowa
.97619 .28256 m
.97619 .28881 L
s
[(2)] .97619 .27006 0 1 Mshowa
.125 Mabswid
.07143 .28256 m
.07143 .28631 L
s
.11905 .28256 m
.11905 .28631 L
s
.16667 .28256 m
.16667 .28631 L
s
.21429 .28256 m
.21429 .28631 L
s
.30952 .28256 m
.30952 .28631 L
s
.35714 .28256 m
.35714 .28631 L
s
.40476 .28256 m
.40476 .28631 L
s
.45238 .28256 m
.45238 .28631 L
s
.54762 .28256 m
.54762 .28631 L
s
.59524 .28256 m
.59524 .28631 L
s
.64286 .28256 m
.64286 .28631 L
s
.69048 .28256 m
.69048 .28631 L
s
.78571 .28256 m
.78571 .28631 L
s
.83333 .28256 m
.83333 .28631 L
s
.88095 .28256 m
.88095 .28631 L
s
.92857 .28256 m
.92857 .28631 L
s
.25 Mabswid
0 .28256 m
1 .28256 L
s
.5 .04199 m
.50625 .04199 L
s
[(-0.75)] .4875 .04199 1 0 Mshowa
.5 .12218 m
.50625 .12218 L
s
[(-0.5)] .4875 .12218 1 0 Mshowa
.5 .20237 m
.50625 .20237 L
s
[(-0.25)] .4875 .20237 1 0 Mshowa
.5 .36275 m
.50625 .36275 L
s
[(0.25)] .4875 .36275 1 0 Mshowa
.5 .44294 m
.50625 .44294 L
s
[(0.5)] .4875 .44294 1 0 Mshowa
.5 .52313 m
.50625 .52313 L
s
[(0.75)] .4875 .52313 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .05803 m
.50375 .05803 L
s
.5 .07407 m
.50375 .07407 L
s
.5 .09011 m
.50375 .09011 L
s
.5 .10615 m
.50375 .10615 L
s
.5 .13822 m
.50375 .13822 L
s
.5 .15426 m
.50375 .15426 L
s
.5 .1703 m
.50375 .1703 L
s
.5 .18633 m
.50375 .18633 L
s
.5 .21841 m
.50375 .21841 L
s
.5 .23445 m
.50375 .23445 L
s
.5 .25049 m
.50375 .25049 L
s
.5 .26652 m
.50375 .26652 L
s
.5 .2986 m
.50375 .2986 L
s
.5 .31464 m
.50375 .31464 L
s
.5 .33068 m
.50375 .33068 L
s
.5 .34671 m
.50375 .34671 L
s
.5 .37879 m
.50375 .37879 L
s
.5 .39483 m
.50375 .39483 L
s
.5 .41086 m
.50375 .41086 L
s
.5 .4269 m
.50375 .4269 L
s
.5 .45898 m
.50375 .45898 L
s
.5 .47502 m
.50375 .47502 L
s
.5 .49105 m
.50375 .49105 L
s
.5 .50709 m
.50375 .50709 L
s
.5 .53917 m
.50375 .53917 L
s
.5 .55521 m
.50375 .55521 L
s
.5 .57124 m
.50375 .57124 L
s
.5 .58728 m
.50375 .58728 L
s
.5 .02596 m
.50375 .02596 L
s
.5 .00992 m
.50375 .00992 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06776 L
.10458 .12092 L
.14415 .16673 L
.18221 .20734 L
.22272 .24715 L
.26171 .28239 L
.30316 .31682 L
.34309 .34728 L
.3815 .37426 L
.42237 .40067 L
.46172 .42405 L
.49955 .44478 L
.53984 .46512 L
.57861 .48313 L
.61984 .50074 L
.65954 .51631 L
.69774 .53012 L
.73838 .54365 L
.77751 .55562 L
.81909 .56731 L
.85916 .57765 L
.89771 .58681 L
.93871 .59578 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oe`3oool0
0`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000
oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool300000=H0oooo003G
0?ooo`030000003oool0oooo0=H0oooo000:0?ooo`030000003oool0oooo0<X0oooo00<000000?oo
o`3oool0eP3oool000/0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`3F0?ooo`00
2`3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo0=H0oooo000<0?ooo`030000003o
ool0oooo0<P0oooo00<000000?ooo`3oool0eP3oool000d0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`3F0?ooo`003P3oool00`000000oooo0?ooo`360?ooo`<00000eP3oool000h0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`3F0?ooo`003`3oool00`000000oooo
0?ooo`350?ooo`030000003oool0oooo0=H0oooo000@0?ooo`030000003oool0oooo09d0oooo1000
00060?ooo`800000203oool00`000000oooo0?ooo`040?ooo`@00000203oool00`000000oooo0?oo
o`3F0?ooo`004@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0eP3oool00140oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=H0oooo000B0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00
4`3oool00`000000oooo0?ooo`2@0?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`@00000
e@3oool001@0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool4000000P0oooo00<000000?ooo`3oool0eP3o
ool001@0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0=H0oooo000E0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0=H0oooo000F0?ooo`030000003oool0oooo09L0
oooo1000000=0?ooo`H00000103oool5000000L0oooo00<000000?ooo`3oool0eP3oool001L0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`3F0?ooo`005`3oool00`000000oooo0?oo
o`2m0?ooo`030000003oool0oooo0=H0oooo000H0?ooo`030000003oool0oooo0;`0oooo0`00003F
0?ooo`006@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo0=H0oooo000J0?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0eP3oool001X0oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`3F0?ooo`006`3oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo0=H0oooo000L0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0eP3oool0
01d0oooo00<000000?ooo`3oool0]`3oool300000=H0oooo000M0?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool0eP3oool001h0oooo00<000000?ooo`3oool0]P3oool00`000000oooo
0?ooo`3F0?ooo`007`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo0=H0oooo000P
0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0eP3oool00200oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`3F0?ooo`008@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo0=H0oooo000R0?ooo`030000003oool0oooo0;80oooo0`00003F0?ooo`008`3o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0=H0oooo000T0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool0eP3oool002@0oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`3F0?ooo`009@3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0=H0
oooo000V0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0eP3oool002L0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`3F0?ooo`00:03oool00`000000oooo0?ooo`2/
0?ooo`<00000eP3oool002P0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`3F0?oo
o`00:@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo0=H0oooo000Z0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0eP3oool002/0oooo00<000000?ooo`3oool0R`3o
ool4000000H0oooo0P0000060?ooo`@00000203oool00`000000oooo0?ooo`3F0?ooo`00:`3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0=H0oooo000/0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0eP3oool002d0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01@3oool400000=D0oooo000^0?ooo`030000003oool0oooo07h0oooo
1P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0=H0oooo000_0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@00000203oool00`000000oooo0?oo
o`3F0?ooo`00<03oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=H0oooo000a0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool00340oooo00<000000?ooo`3o
ool0Q@3oool4000000h0oooo1@0000070?ooo`030000003oool0oooo0=H0oooo000b0?ooo`030000
003oool0oooo0:80oooo00<000000?ooo`3oool0eP3oool003<0oooo00<000000?ooo`3oool0X@3o
ool300000=H0oooo000d0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0eP3oool0
03D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`3F0?ooo`00=P3oool00`000000
oooo0?ooo`2N0?ooo`030000003oool0oooo0=H0oooo000g0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0eP3oool003P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?oo
o`3F0?ooo`00>@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0=H0oooo000j0?oo
o`030000003oool0oooo09X0oooo0`00003F0?ooo`00>P3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0=H0oooo000k0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
eP3oool003`0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`3F0?ooo`00?@3oool0
0`000000oooo0?ooo`2G0?ooo`030000003oool0oooo0=H0oooo000n0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0eP3oool003l0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`3F0?ooo`00@03oool00`000000oooo0?ooo`2D0?ooo`<00000eP3oool00440oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`3F0?ooo`00@P3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0=H0oooo00130?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0eP3oool004@0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3F0?ooo`00
A@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0=H0oooo00160?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0eP3oool004L0oooo00<000000?ooo`3oool0S@3oool3
00000=H0oooo00170?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0eP3oool004P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`3F0?ooo`00B@3oool00`000000oooo
0?ooo`1T0?ooo`@000001P3oool2000000D0oooo1P0000040?ooo`@00000203oool00`000000oooo
0?ooo`3F0?ooo`00BP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`00B`3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0eP3o
ool004`0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0=H0oooo001=0?ooo`030000003oool0oooo05H0oooo1P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo1000003E0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`@00000203oool00`000000
oooo0?ooo`3F0?ooo`00C`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3F0?ooo`00D03oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`3F0?ooo`00D@3oool00`000000oooo0?ooo`1L0?ooo`@000003P3oool4000000D0oooo1@000007
0?ooo`030000003oool0oooo0=H0oooo001B0?ooo`030000003oool0oooo0880oooo00<000000?oo
o`3oool0eP3oool005<0oooo00<000000?ooo`3oool0P@3oool300000=H0oooo001D0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool0eP3oool005D0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`3F0?ooo`00EP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo0=H0oooo001G0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0eP3oool005P0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3F0?ooo`00F@3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo0=H0oooo001J0?ooo`030000003oool0oooo07X0oooo0`00
003F0?ooo`00F`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0=H0oooo001L0?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool0eP3oool005d0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`3F0?ooo`002`3oool6000004d0oooo00<000000?ooo`3oool0
4@3oool7000005h0oooo00<000000?ooo`3oool0H03oool7000005l0oooo1P00000:0?ooo`002`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo000<0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G`3oool30000
06<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0;0?ooo`000P3oool6000000H0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`040?ooo`H000001P3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`1A0?ooo`8000003`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo000;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0:
0?ooo`<00000H@3oool00`000000oooo0?ooo`1Q0?ooo`<00000HP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo000<0?ooo`@00000E`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1Q0?oo
o`@000002`3oool006P0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`3F0?ooo`00
J@3oool00`000000oooo0?ooo`1[0?ooo`<00000eP3oool006X0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`3F0?ooo`00J`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo0=H0oooo001/0?ooo`800000J@3oool00`000000oooo0?ooo`3F0?ooo`00KP3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo0=H0oooo001_0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0eP3oool00700oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`3F0?ooo`00o`00002`00000040oooo000:0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool04P3oool200000180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0000000A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1T0?ooo`040000
003oool0oooo00000680oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00T0oooo001e0?ooo`800000H03oool00`000000oooo0?ooo`3F0?ooo`00M`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0=H0oooo001h0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0eP3oool007T0oooo00<000000?ooo`3oool0F`3oool30000
0=H0oooo001j0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0eP3oool007/0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3F0?ooo`00O03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0=H0oooo001m0?ooo`800000F03oool00`000000oooo0?ooo`3F
0?ooo`00O`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0=H0oooo00200?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0eP3oool00840oooo00<000000?ooo`3oool0
D`3oool300000=H0oooo00220?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0eP3o
ool008<0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00250?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0eP3oool008H0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`3F0?ooo`00Q`3oool2000004h0oooo00<000000?ooo`3oool0eP3oool008T0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`3F0?ooo`00RP3oool00`000000oooo0?ooo`1:
0?ooo`<00000eP3oool008/0oooo0P00001:0?ooo`030000003oool0oooo0=H0oooo002=0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0eP3oool008h0oooo0P0000170?ooo`030000
003oool0oooo0=H0oooo002@0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0eP3o
ool00940oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3F0?ooo`00TP3oool20000
04<0oooo00<000000?ooo`3oool0eP3oool009@0oooo00<000000?ooo`3oool0@03oool300000=H0
oooo002E0?ooo`800000@03oool00`000000oooo0?ooo`3F0?ooo`00U`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo0=H0oooo002H0?ooo`8000005P3oool4000000H0oooo0P000005
0?ooo`H00000103oool4000000P0oooo00<000000?ooo`3oool0eP3oool009X0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0eP3oool009/0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0=H0oooo002L0?ooo`8000004@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`@00000e@3oool009h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0=H0oooo002O0?ooo`8000003P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool4000000P0oooo00<0
00000?ooo`3oool0eP3oool00:40oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool00:80oooo0P00000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3F0?oo
o`00Y03oool00`000000oooo0?ooo`090?ooo`@000003P3oool4000000D0oooo1@0000070?ooo`03
0000003oool0oooo0=H0oooo002U0?ooo`800000<03oool00`000000oooo0?ooo`3F0?ooo`00Y`3o
ool00`000000oooo0?ooo`0]0?ooo`<00000eP3oool00:P0oooo0P00000]0?ooo`030000003oool0
oooo0=H0oooo002Z0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0eP3oool00:/0
oooo0P00000Z0?ooo`030000003oool0oooo0=H0oooo002]0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0eP3oool00:h0oooo0P00000W0?ooo`030000003oool0oooo0=H0oooo002`
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0eP3oool00;40oooo0P00000T0?oo
o`<00000eP3oool00;<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3F0?ooo`00
]03oool200000240oooo00<000000?ooo`3oool0eP3oool00;H0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`3F0?ooo`00]`3oool2000001h0oooo00<000000?ooo`3oool0eP3oool0
0;T0oooo0P00000L0?ooo`030000003oool0oooo0=H0oooo002k0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0eP3oool00;`0oooo0P00000I0?ooo`<00000eP3oool00;h0oooo0P00
000G0?ooo`030000003oool0oooo0=H0oooo00300?ooo`8000005@3oool00`000000oooo0?ooo`3F
0?ooo`00`P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0=H0oooo00330?ooo`80
00004P3oool00`000000oooo0?ooo`3F0?ooo`00a@3oool200000100oooo00<000000?ooo`3oool0
eP3oool00<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3F0?ooo`00b03oool2
000000d0oooo0`00003F0?ooo`00bP3oool2000000/0oooo00<000000?ooo`3oool0eP3oool00<`0
oooo0P0000090?ooo`030000003oool0oooo0=H0oooo002i0?ooo`@000001P3oool2000000H0oooo
100000080?ooo`030000003oool0oooo0=H0oooo002h0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<0
00000?ooo`3oool0eP3oool00;P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool0eP3oool00;P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`8000000P3o
ool00`000000oooo0?ooo`3F0?ooo`00^03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool600000=D0oooo002h0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool4000000P0oooo0P00003G0?ooo`00^03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool010000000
oooo00000000003E0?ooo`00^03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool200000=<0oooo002i0?ooo`@0
00003P3oool5000000L0oooo00<000000?ooo`3oool00`3oool200000=40oooo003G0?ooo`030000
003oool0oooo00D0oooo0P00003?0?ooo`00e`3oool00`000000oooo0?ooo`070?ooo`800000c@3o
ool00=L0oooo0`0000090?ooo`800000b`3oool00=L0oooo00<000000?ooo`3oool02`3oool20000
0<T0oooo003G0?ooo`030000003oool0oooo00d0oooo0`0000360?ooo`00e`3oool00`000000oooo
0?ooo`0@0?ooo`800000a03oool00=L0oooo00<000000?ooo`3oool04P3oool200000<80oooo003G
0?ooo`030000003oool0oooo01@0oooo0P0000300?ooo`00e`3oool00`000000oooo0?ooo`0F0?oo
o`800000_P3oool00=L0oooo0`00000H0?ooo`800000_03oool00=L0oooo00<000000?ooo`3oool0
6P3oool200000;X0oooo003G0?ooo`030000003oool0oooo01`0oooo0P00002h0?ooo`00e`3oool0
0`000000oooo0?ooo`0N0?ooo`<00000]@3oool00=L0oooo00<000000?ooo`3oool08@3oool20000
0;<0oooo003G0?ooo`030000003oool0oooo02<0oooo0P00002a0?ooo`00e`3oool00`000000oooo
0?ooo`0U0?ooo`800000[`3oool00=L0oooo0`00000W0?ooo`800000[@3oool00=L0oooo00<00000
0?ooo`3oool0:@3oool200000:/0oooo003G0?ooo`030000003oool0oooo02/0oooo0P00002Y0?oo
o`00e`3oool00`000000oooo0?ooo`0]0?ooo`800000Y`3oool00=L0oooo00<000000?ooo`3oool0
;`3oool300000:@0oooo003G0?ooo`030000003oool0oooo0380oooo0`00002Q0?ooo`00e`3oool3
000003D0oooo0`00002N0?ooo`00e`3oool00`000000oooo0?ooo`0h0?ooo`<00000V`3oool00=L0
oooo00<000000?ooo`3oool0>`3oool3000009P0oooo003G0?ooo`030000003oool0oooo03h0oooo
0`00002E0?ooo`00/03oool4000000H0oooo0P0000080?ooo`030000003oool0oooo00@0oooo1000
00080?ooo`030000003oool0oooo0440oooo0`00002B0?ooo`00[`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo0P00002@
0?ooo`00[`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04H0oooo0`00002=0?oo
o`00[`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`@00000B03oool3000008X0oooo002_0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0C03oool2000008P0oooo002_0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`@00000203o
ool00`000000oooo0?ooo`1>0?ooo`<00000Q@3oool00:l0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1A0?ooo`<00000PP3oool00:l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo05@0oooo0`00001o0?ooo`00/03oool4000000d0
oooo1P0000040?ooo`D000001`3oool00`000000oooo0?ooo`1G0?ooo`<00000O03oool00=L0oooo
00<000000?ooo`3oool0FP3oool2000007X0oooo003G0?ooo`<00000G03oool3000007L0oooo003G
0?ooo`030000003oool0oooo05l0oooo0`00001d0?ooo`00e`3oool00`000000oooo0?ooo`1R0?oo
o`<00000L@3oool00=L0oooo00<000000?ooo`3oool0I@3oool4000006d0oooo003G0?ooo`030000
003oool0oooo06T0oooo0`00001Z0?ooo`00e`3oool00`000000oooo0?ooo`1/0?ooo`<00000I`3o
ool00=L0oooo00<000000?ooo`3oool0K`3oool4000006<0oooo003G0?ooo`<00000L`3oool30000
0600oooo003G0?ooo`030000003oool0oooo07H0oooo1000001L0?ooo`00e`3oool00`000000oooo
0?ooo`1j0?ooo`<00000F@3oool00=L0oooo00<000000?ooo`3oool0O@3oool4000005D0oooo003G
0?ooo`030000003oool0oooo0840oooo1000001A0?ooo`00e`3oool00`000000oooo0?ooo`250?oo
o`<00000CP3oool00=L0oooo00<000000?ooo`3oool0R03oool4000004X0oooo003G0?ooo`<00000
S03oool3000004L0oooo003G0?ooo`030000003oool0oooo08l0oooo0`0000140?ooo`00e`3oool0
0`000000oooo0?ooo`2B0?ooo`@00000@03oool00=L0oooo00<000000?ooo`3oool0UP3oool40000
03`0oooo003G0?ooo`030000003oool0oooo09X0oooo1000000h0?ooo`00e`3oool00`000000oooo
0?ooo`2N0?ooo`@00000=03oool00=L0oooo00<000000?ooo`3oool0XP3oool400000300oooo003G
0?ooo`<00000YP3oool5000002/0oooo003G0?ooo`030000003oool0oooo0:/0oooo1000000W0?oo
o`00e`3oool00`000000oooo0?ooo`2_0?ooo`@000008`3oool00<X0oooo1`0000060?ooo`030000
003oool0oooo0;<0oooo1000000O0?ooo`00c@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0;L0oooo1@00000J0?ooo`00c@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0;`0oooo1P00000D0?ooo`00c@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0<80oooo1P00000>0?ooo`00c@3oool00`000000oooo0?ooo`070?ooo`@00000a`3oool3000000/0
oooo003=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0eP3oool00<d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`3F0?ooo`00b`3oool3000000T0oooo00<00000
0?ooo`3oool0eP3oool00<d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3F0?oo
o`00e`3oool00`000000oooo0?ooo`3F0?ooo`00e`3oool00`000000oooo0?ooo`3F0?ooo`00\
\>"],
  ImageRangeCache->{{{108, 395}, {669.875, 492.938}} -> {-3.6958, 4.49602, \
0.014695, 0.010908}}]
}, Open  ]],

Cell["Eine nicht-normierte Nutzenfunktion vom Quadratwurzeltyp:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SqrtUtility[2, \(-0.3\)]\)[x]\)], "Input"],

Cell[BoxData[
    \(2 - 0.3`\ \@x\)], "Output"]
}, Open  ]],

Cell["Diesselbe Funktion in \[UDoubleDot]ber [20;70] normierter Gestalt:", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(SqrtUtility[2, \(-0.3\), Normalize \[Rule] {20, 70}]\)[x], {x, 
          10, 100}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.155321 0.335243 [
[.21429 .14282 -6 -9 ]
[.21429 .14282 6 0 ]
[.40476 .14282 -6 -9 ]
[.40476 .14282 6 0 ]
[.59524 .14282 -6 -9 ]
[.59524 .14282 6 0 ]
[.78571 .14282 -6 -9 ]
[.78571 .14282 6 0 ]
[.97619 .14282 -9 -9 ]
[.97619 .14282 9 0 ]
[.01131 .07151 -30 -4.5 ]
[.01131 .07151 0 4.5 ]
[.01131 .23913 -24 -4.5 ]
[.01131 .23913 0 4.5 ]
[.01131 .32294 -18 -4.5 ]
[.01131 .32294 0 4.5 ]
[.01131 .40675 -24 -4.5 ]
[.01131 .40675 0 4.5 ]
[.01131 .49056 -6 -4.5 ]
[.01131 .49056 0 4.5 ]
[.01131 .57437 -24 -4.5 ]
[.01131 .57437 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .15532 m
.21429 .16157 L
s
[(20)] .21429 .14282 0 1 Mshowa
.40476 .15532 m
.40476 .16157 L
s
[(40)] .40476 .14282 0 1 Mshowa
.59524 .15532 m
.59524 .16157 L
s
[(60)] .59524 .14282 0 1 Mshowa
.78571 .15532 m
.78571 .16157 L
s
[(80)] .78571 .14282 0 1 Mshowa
.97619 .15532 m
.97619 .16157 L
s
[(100)] .97619 .14282 0 1 Mshowa
.125 Mabswid
.07143 .15532 m
.07143 .15907 L
s
.11905 .15532 m
.11905 .15907 L
s
.16667 .15532 m
.16667 .15907 L
s
.2619 .15532 m
.2619 .15907 L
s
.30952 .15532 m
.30952 .15907 L
s
.35714 .15532 m
.35714 .15907 L
s
.45238 .15532 m
.45238 .15907 L
s
.5 .15532 m
.5 .15907 L
s
.54762 .15532 m
.54762 .15907 L
s
.64286 .15532 m
.64286 .15907 L
s
.69048 .15532 m
.69048 .15907 L
s
.7381 .15532 m
.7381 .15907 L
s
.83333 .15532 m
.83333 .15907 L
s
.88095 .15532 m
.88095 .15907 L
s
.92857 .15532 m
.92857 .15907 L
s
.25 Mabswid
0 .15532 m
1 .15532 L
s
.02381 .07151 m
.03006 .07151 L
s
[(-0.25)] .01131 .07151 1 0 Mshowa
.02381 .23913 m
.03006 .23913 L
s
[(0.25)] .01131 .23913 1 0 Mshowa
.02381 .32294 m
.03006 .32294 L
s
[(0.5)] .01131 .32294 1 0 Mshowa
.02381 .40675 m
.03006 .40675 L
s
[(0.75)] .01131 .40675 1 0 Mshowa
.02381 .49056 m
.03006 .49056 L
s
[(1)] .01131 .49056 1 0 Mshowa
.02381 .57437 m
.03006 .57437 L
s
[(1.25)] .01131 .57437 1 0 Mshowa
.125 Mabswid
.02381 .08827 m
.02756 .08827 L
s
.02381 .10503 m
.02756 .10503 L
s
.02381 .1218 m
.02756 .1218 L
s
.02381 .13856 m
.02756 .13856 L
s
.02381 .17208 m
.02756 .17208 L
s
.02381 .18885 m
.02756 .18885 L
s
.02381 .20561 m
.02756 .20561 L
s
.02381 .22237 m
.02756 .22237 L
s
.02381 .25589 m
.02756 .25589 L
s
.02381 .27266 m
.02756 .27266 L
s
.02381 .28942 m
.02756 .28942 L
s
.02381 .30618 m
.02756 .30618 L
s
.02381 .3397 m
.02756 .3397 L
s
.02381 .35647 m
.02756 .35647 L
s
.02381 .37323 m
.02756 .37323 L
s
.02381 .38999 m
.02756 .38999 L
s
.02381 .42352 m
.02756 .42352 L
s
.02381 .44028 m
.02756 .44028 L
s
.02381 .45704 m
.02756 .45704 L
s
.02381 .4738 m
.02756 .4738 L
s
.02381 .50733 m
.02756 .50733 L
s
.02381 .52409 m
.02756 .52409 L
s
.02381 .54085 m
.02756 .54085 L
s
.02381 .55761 m
.02756 .55761 L
s
.02381 .05475 m
.02756 .05475 L
s
.02381 .03799 m
.02756 .03799 L
s
.02381 .02122 m
.02756 .02122 L
s
.02381 .00446 m
.02756 .00446 L
s
.02381 .59114 m
.02756 .59114 L
s
.02381 .6079 m
.02756 .6079 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.15382 .55748 L
.19174 .51406 L
.22736 .47758 L
.26161 .44539 L
.29806 .4136 L
.33316 .38493 L
.37046 .35619 L
.4064 .32994 L
.44097 .30582 L
.47775 .28123 L
.51316 .25849 L
.54722 .23738 L
.58347 .21565 L
.61837 .19538 L
.65547 .17448 L
.69121 .15493 L
.72558 .1366 L
.76216 .11759 L
.79738 .09972 L
.8348 .08118 L
.87086 .06371 L
.90556 .04725 L
.94246 .0301 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo
000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00340oooo0`00003o0?ooogd0oooo000a0?oo
o`030000003oool0oooo0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00
<@3oool00`000000oooo0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooK@3o
ool2000000h0oooo000a0?ooo`030000003oool0oooo0?l0ooooJ`3oool200000100oooo000a0?oo
o`<00000o`3ooomY0?ooo`8000004P3oool00340oooo00<000000?ooo`3oool0o`3ooomW0?ooo`80
0000503oool00340oooo00<000000?ooo`3oool0o`3ooomU0?ooo`8000005P3oool00340oooo00<0
00000?ooo`3oool0o`3ooomS0?ooo`800000603oool00340oooo00<000000?ooo`3oool0o`3ooomQ
0?ooo`8000006P3oool00340oooo00<000000?ooo`3oool0o`3ooomO0?ooo`800000703oool00340
oooo00<000000?ooo`3oool0o`3ooomM0?ooo`8000007P3oool00340oooo0`00003o0?oooe/0oooo
0P00000P0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooeT0oooo0P00000R0?ooo`00<@3oool0
0`000000oooo0?ooo`3o0?oooeL0oooo0P00000T0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oo
oeD0oooo0P00000V0?ooo`00<@3oool00`000000oooo0?ooo`3o0?oooe80oooo0`00000X0?ooo`00
<@3oool00`000000oooo0?ooo`3o0?oooe00oooo0P00000[0?ooo`00<@3oool300000?l0ooooCP3o
ool2000002d0oooo000a0?ooo`030000003oool0oooo0?l0ooooB`3oool3000002l0oooo000a0?oo
o`030000003oool0oooo0?l0ooooB@3oool200000380oooo000;0?ooo`@000001P3oool2000000D0
oooo1P0000040?ooo`@000001`3oool00`000000oooo0?ooo`3o0?ooodL0oooo0P00000d0?ooo`00
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0o`3ooom50?ooo`800000=P3oool000X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3o0?oood<0oooo0P00000h0?ooo`002P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo@@3oool2000003X0oooo00000`3oool0000000000004
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool400000?l0oooo?P3oool2000003`0oooo000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`@000001`3oool00`000000oooo0?ooo`3o0?ooocd0oooo0P00000n0?ooo`002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`80
0000@03oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?l0oooo>@3oool200000480oooo000;0?ooo`@000003P3oool4000000D0oooo1@00
00060?ooo`030000003oool0oooo0?l0oooo=`3oool2000004@0oooo000a0?ooo`030000003oool0
oooo0?l0oooo=@3oool2000004H0oooo000a0?ooo`<00000o`3ooolc0?ooo`800000B03oool00340
oooo00<000000?ooo`3oool0o`3ooola0?ooo`800000BP3oool00340oooo00<000000?ooo`3oool0
o`3oool_0?ooo`800000C03oool00340oooo00<000000?ooo`3oool0o`3oool]0?ooo`800000CP3o
ool00340oooo00<000000?ooo`3oool0o`3oool[0?ooo`800000D03oool00340oooo00<000000?oo
o`3oool0o`3ooolY0?ooo`800000DP3oool00340oooo00<000000?ooo`3oool0o`3ooolW0?ooo`80
0000E03oool00340oooo0`00003o0?ooobD0oooo0P00001F0?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooob<0oooo0P00001H0?ooo`00<@3oool00`000000oooo0?ooo`0o0?ooo`H00000103oool4
000003d0oooo100000040?ooo`@00000?P3oool4000000@0oooo1000000l0?ooo`H000000`3oool4
000003P0oooo1`0000030?ooo`@000001@3oool4000000@0oooo000a0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00@3oool00340oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0>03oool300000080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0h0?ooo`H000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0
oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0=`3oool20000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`010?ooo`00<@3oool300000480oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`0000000P00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3oool200000080oooo1000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo0040oooo000a0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P0000030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`010?ooo`00<@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0340oooo0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`010?ooo`00<@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02l0oooo0P0000070?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo03H0oooo0`0000050?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040
oooo000a0?ooo`030000003oool0oooo0400oooo100000050?ooo`@00000?P3oool2000000D0oooo
100000100?ooo`<000000`3oool400000300oooo0P00000:0?ooo`@000001@3oool4000003/0oooo
00<000000?ooo`3oool0103oool4000000D0oooo100000040?ooo`00<@3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo0P00001/0?ooo`00<@3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0P00001^
0?ooo`00<@3oool300000?l0oooo2`3oool200000700oooo000a0?ooo`030000003oool0oooo0?l0
oooo2@3oool200000780oooo000a0?ooo`030000003oool0oooo0?l0oooo1`3oool2000007@0oooo
000a0?ooo`030000003oool0oooo0?l0oooo1@3oool2000007H0oooo000a0?ooo`030000003oool0
oooo0?l0oooo0`3oool2000007P0oooo000a0?ooo`030000003oool0oooo0?l0oooo0@3oool20000
07X0oooo000X0?ooool00000Q00000050?ooo`00<@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo0`00000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0<0?ooo`00<@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00`0oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo000a0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo01`0oooo0P00000X0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0303oool0
0340oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`210?ooo`00<@3oool00`000000
oooo0?ooo`3f0?ooo`800000Q03oool00340oooo00<000000?ooo`3oool0m03oool2000008H0oooo
000a0?ooo`<00000lP3oool2000008P0oooo000a0?ooo`030000003oool0oooo0?40oooo00<00000
0?ooo`3oool0R03oool00340oooo00<000000?ooo`3oool0k`3oool2000008/0oooo000a0?ooo`03
0000003oool0oooo0>d0oooo0P00002=0?ooo`00<@3oool00`000000oooo0?ooo`3[0?ooo`800000
S`3oool00340oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`2?0?ooo`00<@3oool3
00000>P0oooo0P00002B0?ooo`00<@3oool00`000000oooo0?ooo`3V0?ooo`800000U03oool00340
oooo00<000000?ooo`3oool0i03oool2000009H0oooo000a0?ooo`030000003oool0oooo0><0oooo
00<000000?ooo`3oool0UP3oool00340oooo00<000000?ooo`3oool0h@3oool2000009T0oooo000a
0?ooo`030000003oool0oooo0=l0oooo0P00002K0?ooo`00<@3oool00`000000oooo0?ooo`3M0?oo
o`800000W@3oool00340oooo0`00003L0?ooo`030000003oool0oooo09d0oooo000a0?ooo`030000
003oool0oooo0=X0oooo0P00002P0?ooo`00<@3oool00`000000oooo0?ooo`3H0?ooo`800000XP3o
ool00340oooo00<000000?ooo`3oool0eP3oool200000:@0oooo000a0?ooo`030000003oool0oooo
0=D0oooo00<000000?ooo`3oool0Y03oool00340oooo00<000000?ooo`3oool0d`3oool200000:L0
oooo000a0?ooo`<00000d@3oool200000:T0oooo000a0?ooo`030000003oool0oooo0<l0oooo0P00
002[0?ooo`00<@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0:/0oooo000;0?oo
o`@000001P3oool2000000D0oooo1P0000040?ooo`@000001`3oool00`000000oooo0?ooo`3<0?oo
o`800000[P3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0<X0oooo0P00002`0?ooo`002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0<P0oooo0P00002b0?ooo`002P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0/P3oool000X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0103oool400000<@0oooo0P00002e0?ooo`002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool4000000L0oooo00<00000
0?ooo`3oool0``3oool200000;L0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0;L0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`300?ooo`80
0000^P3oool000/0oooo1000000>0?ooo`@000001@3oool5000000H0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`2j0?ooo`00<@3oool00`000000oooo0?ooo`2m0?ooo`800000_@3o
ool00340oooo0`00002k0?ooo`800000_`3oool00340oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`2o0?ooo`00<@3oool00`000000oooo0?ooo`2h0?ooo`800000`P3oool00340oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`320?ooo`00<@3oool00`000000oooo0?oo
o`2e0?ooo`800000a@3oool00340oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`35
0?ooo`00<@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0<H0oooo000a0?ooo`<0
0000/@3oool200000<T0oooo000a0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
b@3oool00340oooo00<000000?ooo`3oool0[P3oool200000<`0oooo000a0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool0c03oool00340oooo00<000000?ooo`3oool0Z`3oool20000
0<l0oooo000a0?ooo`030000003oool0oooo0:T0oooo0P00003A0?ooo`00<@3oool300000:P0oooo
00<000000?ooo`3oool0d@3oool00340oooo00<000000?ooo`3oool0YP3oool200000=@0oooo000a
0?ooo`030000003oool0oooo0:@0oooo0P00003F0?ooo`00<@3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo0=H0oooo000a0?ooo`030000003oool0oooo0:40oooo0P00003I0?ooo`00
<@3oool00`000000oooo0?ooo`2O0?ooo`800000f`3oool00340oooo0`00002N0?ooo`030000003o
ool0oooo0=/0oooo000a0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0g03oool0
0340oooo00<000000?ooo`3oool0V`3oool200000=l0oooo000D0?ooo`@000001P3oool2000000H0
oooo100000070?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0g`3oool001<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`3P0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2G0?ooo`800000h`3oool001<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`3S0?ooo`004`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool4000009@0oooo00<000000?oo
o`3oool0i03oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`@0
00001`3oool00`000000oooo0?ooo`2C0?ooo`800000i`3oool001<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`3W0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo0>P0oooo000D0?ooo`@000003P3oool5000000H0oooo00<000000?ooo`3oool0S`3oool2
00000>/0oooo000a0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0j`3oool00340
oooo0`00002=0?ooo`030000003oool0oooo0>`0oooo000a0?ooo`030000003oool0oooo08/0oooo
0P00003_0?ooo`00<@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0>l0oooo000a
0?ooo`030000003oool0oooo08P0oooo0P00003b0?ooo`00<@3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo0?80oooo000a0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0l`3oool00340oooo00<000000?ooo`3oool0Q03oool200000?H0oooo000a0?ooo`<00000P`3o
ool00`000000oooo0?ooo`3f0?ooo`00<@3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0?L0oooo000a0?ooo`030000003oool0oooo0800oooo0P00003j0?ooo`00<@3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo0?X0oooo000a0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0n`3oool00340oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`3l0?ooo`00<@3oool3000007/0oooo0P00003o0?ooo`00<@3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0?l0oooo000a0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0o`3oool10?ooo`00<@3oool00`000000oooo0?ooo`1g0?ooo`800000o`3oool40?ooo`00<@3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0?l0oooo103oool00340oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`3o0?ooo`D0oooo000a0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool0o`3oool60?ooo`00<@3oool300000780oooo0P00003o0?ooo`T0
oooo000a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3oool90?ooo`00<@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0?l0oooo2P3oool000/0oooo10000006
0?ooo`800000203oool00`000000oooo0?ooo`040?ooo`@000001`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0?l0oooo2`3oool000X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`800000o`3oool>0?oo
o`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3o
ool0o`3oool>0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`@00000JP3oool00`000000oooo
0?ooo`3o0?ooo`l0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3o
ool200000?l0oooo4P3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo100000070?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0o`3ooolB0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3o0?oooa@0
oooo000;0?ooo`@000003@3oool6000000@0oooo1@0000060?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0o`3ooolE0?ooo`00<@3oool00`000000oooo0?ooo`1S0?ooo`800000o`3o
oolH0?ooo`00<@3oool300000680oooo00<000000?ooo`3oool0o`3ooolH0?ooo`00<@3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0oooo6@3oool00340oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`3o0?oooaX0oooo000a0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`00<@3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0?l0oooo703oool00340oooo00<000000?ooo`3oool0G03oool200000?l0oooo7`3oool0
0340oooo0`00001K0?ooo`030000003oool0oooo0?l0oooo7`3oool00340oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`3o0?ooob00oooo000a0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0o`3ooolQ0?ooo`00<@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0?l0oooo8P3oool00340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o
0?ooob<0oooo000a0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`00<@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo9@3oool00340oooo
0`00001D0?ooo`030000003oool0oooo0?l0oooo9P3oool00340oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`3o0?ooobL0oooo000a0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0o`3ooolX0?ooo`00<@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0?l0oooo:@3oool00340oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3o0?ooobX0
oooo000a0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00<@3o
ool3000004h0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00<@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0?l0oooo;@3oool00340oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`3o0?ooobh0oooo000U0?ooo`L000001@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0?l0oooo;`3oool002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo<03oool002P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo<@3oool002P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0?l0oooo<P3oool0
02P0oooo00<000000?ooo`3oool01P3oool4000004H0oooo00<000000?ooo`3oool0o`3ooolc0?oo
o`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0o`3ooold0?ooo`00:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0o`3ooole0?ooo`009P3oool3000000P0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`3o0?ooocH0oooo000X0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?ooocL0oooo000a0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0o`3ooolh0?ooo`00<@3oool300000440oooo00<000000?ooo`3o
ool0o`3oooli0?ooo`00<@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0oooo
>P3oool00340oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oooc/0oooo000a
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00<@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0oooo?@3oool00340oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`3o0?oooch0oooo000a0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0o`3ooolo0?ooo`00<@3oool3000003X0oooo00<000000?ooo`3oool0o`3o
oom00?ooo`00<@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo@03oool0
0340oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oood40oooo000a0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00<@3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0?l0oooo@`3oool00340oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`3o0?oood@0oooo000a0?ooo`<00000=@3oool00`000000oooo0?ooo`3o
0?ooodD0oooo000a0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooom60?oo
o`00<@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooA`3oool00340oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooodL0oooo000a0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0o`3ooom80?ooo`00<@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0?l0ooooB@3oool00340oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`3o0?ooodX0oooo000a0?ooo`<00000;`3oool00`000000oooo0?ooo`3o0?oood/0
oooo000a0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00<@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooC03oool000X0oooo1`000004
0?ooo`8000001@3oool6000000@0oooo100000070?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0o`3ooom=0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`003@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooC`3oool000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo1000000Z0?ooo`03
0000003oool0oooo0?l0ooooC`3oool000d0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`3o0?oooe00oooo000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3o
ool4000000L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?oooe40oooo000=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o
0?oooe80oooo000;0?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0?l0ooooD`3oool000d0oooo00<000000?ooo`3oool03@3oool4000000D0oooo1@0000060?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00<@3oool3000002H0oooo
00<000000?ooo`3oool0o`3ooomD0?ooo`00<@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0?l0ooooE@3oool00340oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o
0?oooeH0oooo000a0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooomF0?oo
o`00<@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooE`3oool00340oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?oooeP0oooo000a0?ooo`030000003o
ool0oooo0?l0ooooO@3oool00340oooo0`00003o0?ooogd0oooo000a0?ooo`030000003oool0oooo
0?l0ooooO@3oool00340oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00<@3oool00`000000oooo
0?ooo`3o0?ooogd0oooo000a0?ooo`030000003oool0oooo0?l0ooooO@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00001\
\>"],
  ImageRangeCache->{{{108, 395}, {389.625, 212.688}} -> {-57.689, 1.90008, \
0.408522, 0.0116056}}]
}, Open  ]],

Cell["\<\
Bernoullis logarithmischer Nutzen (normiert f\[UDoubleDot]r Geldbetr\
\[ADoubleDot]ge von 1 bis 100):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogUtility[1, 1, Normalize \[Rule] {1, 100}]\)[x]\)], "Input"],

Cell[BoxData[
    \(Log[x]\/Log[100]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mischung von Nutzenwerten", "Subsection"],

Cell["\<\
Eine Reihe von Nutzenwerten (utab) wird auf den Maximalwert umax bezogen und \
mit dem Gewichtsvektor (gvek) gemischt:\
\>", "Text"],

Cell[BoxData[{
    \(\(utab = {5, 7, 4, 8, 8, 7, 5, 10, 8};\)\), "\[IndentingNewLine]", 
    \(\(umax = 10;\)\), "\[IndentingNewLine]", 
    \(\(gvek = {5, 3, 5, 3, 2, 2, 2, 4, 3};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompoundUtility[utab, umax, gvek]\)], "Input"],

Cell[BoxData[
    \(97\/145\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Zahlungsreihen", "Section"],

Cell[CellGroupData[{

Cell["Barwert", "Subsection"],

Cell["Zahlungsreihe: c, Vektor der Diskontierungsfaktoren: df", "Text"],

Cell[BoxData[{
    \(\(c = {\(-300\), 105, 105, 150};\)\), "\[IndentingNewLine]", 
    \(\(df = {1.025, 1.035, 1.045};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PresentValue[c, df]\)], "Input"],

Cell[BoxData[
    \(36.71796380955284`\)], "Output"]
}, Open  ]],

Cell["Barwert der Zahlungsreihe c bei kalkulatorischem Zinssatz r:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c = {\(-20000\), 4000, 14000, 5000};\)\), "\[IndentingNewLine]", 
    \(\(r = 0.0035;\)\), "\[IndentingNewLine]", 
    \(PresentValueAtRate[c, r]\)}], "Input"],

Cell[BoxData[
    \(2836.426306008385`\)], "Output"]
}, Open  ]],

Cell["Verlauf des Barwerts im Zinsintervall von 1 % bis 5 %:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PresentValueGraph[c, 0.01, 0.05]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 23.8095 -0.269931 0.000344139 [
[.2619 .0445 -12 -9 ]
[.2619 .0445 12 0 ]
[.5 .0445 -12 -9 ]
[.5 .0445 12 0 ]
[.7381 .0445 -12 -9 ]
[.7381 .0445 12 0 ]
[.97619 .0445 -12 -9 ]
[.97619 .0445 12 0 ]
[.01131 .07421 -24 -4.5 ]
[.01131 .07421 0 4.5 ]
[.01131 .16024 -24 -4.5 ]
[.01131 .16024 0 4.5 ]
[.01131 .24628 -24 -4.5 ]
[.01131 .24628 0 4.5 ]
[.01131 .33231 -24 -4.5 ]
[.01131 .33231 0 4.5 ]
[.01131 .41835 -24 -4.5 ]
[.01131 .41835 0 4.5 ]
[.01131 .50438 -24 -4.5 ]
[.01131 .50438 0 4.5 ]
[.01131 .59042 -24 -4.5 ]
[.01131 .59042 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .057 m
.2619 .06325 L
s
[(0.02)] .2619 .0445 0 1 Mshowa
.5 .057 m
.5 .06325 L
s
[(0.03)] .5 .0445 0 1 Mshowa
.7381 .057 m
.7381 .06325 L
s
[(0.04)] .7381 .0445 0 1 Mshowa
.97619 .057 m
.97619 .06325 L
s
[(0.05)] .97619 .0445 0 1 Mshowa
.125 Mabswid
.07143 .057 m
.07143 .06075 L
s
.11905 .057 m
.11905 .06075 L
s
.16667 .057 m
.16667 .06075 L
s
.21429 .057 m
.21429 .06075 L
s
.30952 .057 m
.30952 .06075 L
s
.35714 .057 m
.35714 .06075 L
s
.40476 .057 m
.40476 .06075 L
s
.45238 .057 m
.45238 .06075 L
s
.54762 .057 m
.54762 .06075 L
s
.59524 .057 m
.59524 .06075 L
s
.64286 .057 m
.64286 .06075 L
s
.69048 .057 m
.69048 .06075 L
s
.78571 .057 m
.78571 .06075 L
s
.83333 .057 m
.83333 .06075 L
s
.88095 .057 m
.88095 .06075 L
s
.92857 .057 m
.92857 .06075 L
s
.25 Mabswid
0 .057 m
1 .057 L
s
.02381 .07421 m
.03006 .07421 L
s
[(1000)] .01131 .07421 1 0 Mshowa
.02381 .16024 m
.03006 .16024 L
s
[(1250)] .01131 .16024 1 0 Mshowa
.02381 .24628 m
.03006 .24628 L
s
[(1500)] .01131 .24628 1 0 Mshowa
.02381 .33231 m
.03006 .33231 L
s
[(1750)] .01131 .33231 1 0 Mshowa
.02381 .41835 m
.03006 .41835 L
s
[(2000)] .01131 .41835 1 0 Mshowa
.02381 .50438 m
.03006 .50438 L
s
[(2250)] .01131 .50438 1 0 Mshowa
.02381 .59042 m
.03006 .59042 L
s
[(2500)] .01131 .59042 1 0 Mshowa
.125 Mabswid
.02381 .09142 m
.02756 .09142 L
s
.02381 .10862 m
.02756 .10862 L
s
.02381 .12583 m
.02756 .12583 L
s
.02381 .14304 m
.02756 .14304 L
s
.02381 .17745 m
.02756 .17745 L
s
.02381 .19466 m
.02756 .19466 L
s
.02381 .21186 m
.02756 .21186 L
s
.02381 .22907 m
.02756 .22907 L
s
.02381 .26348 m
.02756 .26348 L
s
.02381 .28069 m
.02756 .28069 L
s
.02381 .2979 m
.02756 .2979 L
s
.02381 .31511 m
.02756 .31511 L
s
.02381 .34952 m
.02756 .34952 L
s
.02381 .36673 m
.02756 .36673 L
s
.02381 .38393 m
.02756 .38393 L
s
.02381 .40114 m
.02756 .40114 L
s
.02381 .43555 m
.02756 .43555 L
s
.02381 .45276 m
.02756 .45276 L
s
.02381 .46997 m
.02756 .46997 L
s
.02381 .48717 m
.02756 .48717 L
s
.02381 .52159 m
.02756 .52159 L
s
.02381 .5388 m
.02756 .5388 L
s
.02381 .556 m
.02756 .556 L
s
.02381 .57321 m
.02756 .57321 L
s
.02381 .03979 m
.02756 .03979 L
s
.02381 .02259 m
.02756 .02259 L
s
.02381 .00538 m
.02756 .00538 L
s
.02381 .60762 m
.02756 .60762 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .57797 L
.10458 .55047 L
.14415 .52479 L
.18221 .50022 L
.22272 .4742 L
.26171 .44929 L
.30316 .42295 L
.34309 .39771 L
.3815 .37355 L
.42237 .34799 L
.46172 .32351 L
.49955 .30008 L
.53984 .27527 L
.57861 .25152 L
.61984 .22639 L
.65954 .20231 L
.69774 .17927 L
.73838 .15488 L
.77751 .13152 L
.81909 .10683 L
.85916 .08316 L
.89771 .0605 L
.93871 .03652 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000
003oool0oooo0?l0ooooQP3oool002P0oooo0`00003o0?ooohH0oooo000X0?ooo`030000003oool0
oooo0?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000
oooo0?ooo`1:0?ooo`@000001P3oool2000000H0oooo100000040?ooo`H00000?@3oool4000000H0
oooo0P0000060?ooo`@000001@3oool4000003h0oooo100000060?ooo`8000001P3oool4000000H0
oooo1000000n0?ooo`@000001P3oool2000000H0oooo100000050?ooo`@00000103oool002P0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000103oool20000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0040oooo000X0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0040oooo000X0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool6000003d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool002P0oooo0`0000190?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`800000?@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000003h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool002P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000?P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo100000040?ooo`00:03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000003h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0000000000090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`000000?P3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool0BP3oool4000000h0oooo100000050?ooo`@00000?P3oool4000000h0oooo1000
00050?ooo`@00000?P3oool4000000h0oooo100000070?ooo`800000?`3oool4000000h0oooo1000
00050?ooo`D000000`3oool002P0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0
oooo01l0oooo000X0?ooo`<00000o`3ooomR0?ooo`8000008P3oool002P0oooo00<000000?ooo`3o
ool0o`3ooomP0?ooo`800000903oool002P0oooo00<000000?ooo`3oool0o`3ooomN0?ooo`800000
9P3oool002P0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo02H0oooo000X
0?ooo`030000003oool0oooo0?l0ooooF`3oool2000002T0oooo000X0?ooo`030000003oool0oooo
0?l0ooooF@3oool2000002/0oooo000X0?ooo`030000003oool0oooo0?l0ooooE`3oool2000002d0
oooo000O0?ooool00000R@0000090?ooo`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00:03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`800000303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00000`3oool0000000000005000000<0oooo100000050?ooo`@000001@3oool40000
00L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0>03oool200000240oooo00<000000?ooo`3oool0403oool000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0=03oool000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooodd0oooo0P00000g0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooB`3oool2000003T0oooo
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo1000003o0?ooodT0oooo00<000000?ooo`3oool0>@3oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
odP0oooo0P00000l0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooAP3oool2000003h0oooo00020?oo
o`<000001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?ooodD0oooo00<000000?ooo`3oool0?P3oool000@0oooo00<000000?ooo`3oool0103oool4
000000D0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`3o0?oood<0oooo0P000011
0?ooo`00:03oool00`000000oooo0?ooo`3o0?oood80oooo00<000000?ooo`3oool0@@3oool002P0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`800000A03oool002P0oooo0`00003o0?oooch0oooo
0P0000160?ooo`00:03oool00`000000oooo0?ooo`3o0?ooocd0oooo00<000000?ooo`3oool0AP3o
ool002P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`800000B@3oool002P0oooo00<000000?oo
o`3oool0o`3ooolj0?ooo`030000003oool0oooo04T0oooo000X0?ooo`030000003oool0oooo0?l0
oooo>03oool2000004`0oooo000X0?ooo`030000003oool0oooo0?l0oooo=P3oool2000004h0oooo
000X0?ooo`<00000o`3ooole0?ooo`030000003oool0oooo04h0oooo000X0?ooo`030000003oool0
oooo0?l0oooo<`3oool200000540oooo000X0?ooo`030000003oool0oooo0?l0oooo<@3oool20000
05<0oooo000X0?ooo`030000003oool0oooo0?l0oooo;`3oool2000005D0oooo000X0?ooo`030000
003oool0oooo0?l0oooo;P3oool00`000000oooo0?ooo`1E0?ooo`00:03oool00`000000oooo0?oo
o`3o0?ooob`0oooo0P00001H0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooobX0oooo0P00001J
0?ooo`00:03oool300000?l0oooo:03oool2000005`0oooo000X0?ooo`030000003oool0oooo0?l0
oooo9P3oool2000005h0oooo000X0?ooo`030000003oool0oooo0?l0oooo9@3oool00`000000oooo
0?ooo`1N0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooob<0oooo0P00001Q0?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooob40oooo0P00001S0?ooo`00:03oool00`000000oooo0?ooo`3o0?oo
ob00oooo00<000000?ooo`3oool0H`3oool002P0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`80
0000IP3oool002P0oooo0`00003o0?oooa`0oooo0P00001X0?ooo`00:03oool00`000000oooo0?oo
o`3o0?oooa/0oooo00<000000?ooo`3oool0J03oool002P0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`800000J`3oool000030?ooo`000000000000D000000P3oool6000000@0oooo100000050?oo
o`@000001`3oool00`000000oooo0?ooo`3o0?oooaL0oooo0P00001]0?ooo`00103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0oooo5P3oool00`000000oooo0?ooo`1]0?ooo`00103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`800000L03oool000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`040?ooo`@00000o`3ooolB0?ooo`030000003oool0oooo0700oooo00040?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa40oooo0P00001c
0?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo100000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oo
o`l0oooo0P00001e0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`h0oooo00<000000?ooo`3o
ool0M@3oool00080oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`3o0?ooo``0oooo0P00001h0?ooo`00103oool00`000000oooo0?oo
o`040?ooo`@000001@3oool5000000@0oooo100000070?ooo`030000003oool0oooo0?l0oooo2`3o
ool00`000000oooo0?ooo`1h0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooo`T0oooo0P00001k
0?ooo`00:03oool300000?l0oooo1`3oool2000007d0oooo000X0?ooo`030000003oool0oooo0?l0
oooo1P3oool00`000000oooo0?ooo`1m0?ooo`00:03oool00`000000oooo0?ooo`3o0?ooo`@0oooo
0P0000200?ooo`00:03oool00`000000oooo0?ooo`3o0?ooo`80oooo0P0000220?ooo`00:03oool0
0`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool0PP3oool002P0oooo00<000000?oo
o`3oool0oP3oool2000008D0oooo000X0?ooo`030000003oool0oooo0?`0oooo0P0000270?ooo`00
:03oool300000?/0oooo00<000000?ooo`3oool0Q`3oool002P0oooo00<000000?ooo`3oool0n@3o
ool2000008X0oooo000X0?ooo`030000003oool0oooo0?L0oooo0P00002<0?ooo`00:03oool00`00
0000oooo0?ooo`3f0?ooo`030000003oool0oooo08`0oooo000X0?ooo`030000003oool0oooo0?@0
oooo0P00002?0?ooo`00:03oool00`000000oooo0?ooo`3b0?ooo`800000T@3oool002P0oooo00<0
00000?ooo`3oool0l03oool2000009<0oooo000X0?ooo`<00000k`3oool00`000000oooo0?ooo`2C
0?ooo`00:03oool00`000000oooo0?ooo`3]0?ooo`800000UP3oool002P0oooo00<000000?ooo`3o
ool0j`3oool2000009P0oooo000X0?ooo`030000003oool0oooo0>T0oooo0P00002J0?ooo`00:03o
ool00`000000oooo0?ooo`3W0?ooo`800000W03oool002P0oooo00<000000?ooo`3oool0iP3oool0
0`000000oooo0?ooo`2L0?ooo`00:03oool300000>@0oooo0P00002O0?ooo`00:03oool00`000000
oooo0?ooo`3S0?ooo`030000003oool0oooo09l0oooo000X0?ooo`030000003oool0oooo0>40oooo
0P00002R0?ooo`00:03oool00`000000oooo0?ooo`3O0?ooo`800000Y03oool000030?ooo`000000
000000D000000`3oool4000000D0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`3N
0?ooo`030000003oool0oooo0:@0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0g03oool200000:L0oooo0004
0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0=/0oooo
00<000000?ooo`3oool0Y`3oool000@0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0
oooo1000003H0?ooo`800000ZP3oool000@0oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0e`3oool200000:`0oooo00040?ooo`030000003oool0oooo00@0
oooo100000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`2/0?oo
o`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`3D0?ooo`800000[`3oool00080oooo0`0000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3B0?ooo`800000/@3oool000@0oooo00<000000?ooo`3o
ool0103oool5000000@0oooo100000050?ooo`@000001`3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo0;40oooo000X0?ooo`030000003oool0oooo0<l0oooo0P00002d0?ooo`00:03o
ool300000<d0oooo0P00002f0?ooo`00:03oool00`000000oooo0?ooo`3<0?ooo`030000003oool0
oooo0;H0oooo000X0?ooo`030000003oool0oooo0<X0oooo0P00002i0?ooo`00:03oool00`000000
oooo0?ooo`380?ooo`800000^`3oool002P0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`2k0?ooo`00:03oool00`000000oooo0?ooo`350?ooo`800000_P3oool002P0oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`2n0?ooo`00:03oool300000<80oooo0P0000310?oo
o`00:03oool00`000000oooo0?ooo`300?ooo`800000``3oool002P0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`330?ooo`00:03oool00`000000oooo0?ooo`2m0?ooo`800000aP3o
ool002P0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`360?ooo`00:03oool00`00
0000oooo0?ooo`2j0?ooo`800000b@3oool002P0oooo0`00002h0?ooo`800000b`3oool002P0oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`3;0?ooo`00:03oool00`000000oooo0?oo
o`2e0?ooo`800000cP3oool002P0oooo00<000000?ooo`3oool0/`3oool200000=00oooo000X0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool0d03oool002P0oooo00<000000?ooo`3o
ool0/03oool200000=<0oooo000X0?ooo`030000003oool0oooo0:h0oooo0P00003E0?ooo`00:03o
ool300000:d0oooo00<000000?ooo`3oool0e@3oool002P0oooo00<000000?ooo`3oool0Z`3oool2
00000=P0oooo000X0?ooo`030000003oool0oooo0:T0oooo0P00003J0?ooo`0000<0oooo00000000
00001@0000050?ooo`030000003oool0oooo00@0oooo100000050?ooo`@000001`3oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo0=X0oooo00040?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:H0oooo0P00003M0?ooo`00
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Y@3oool00`000000
oooo0?ooo`3M0?ooo`00103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0X`3oool200000>00oooo00040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool400000:40
oooo00<000000?ooo`3oool0h03oool000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0X03oool200000><0oooo00040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo0><0oooo0002
0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0W@3oool200000>H0oooo00040?ooo`030000003oool0oooo00<0oooo1P0000040?oo
o`D00000103oool4000000L0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`3V0?oo
o`00:03oool00`000000oooo0?ooo`2J0?ooo`800000j@3oool002P0oooo0`00002I0?ooo`030000
003oool0oooo0>T0oooo000X0?ooo`030000003oool0oooo09L0oooo0P00003/0?ooo`00:03oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo0>`0oooo000X0?ooo`030000003oool0oooo
09@0oooo0P00003_0?ooo`00:03oool00`000000oooo0?ooo`2B0?ooo`800000l@3oool002P0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`3a0?ooo`00:03oool00`000000oooo0?oo
o`2?0?ooo`800000m03oool002P0oooo0`00002>0?ooo`030000003oool0oooo0?@0oooo000X0?oo
o`030000003oool0oooo08`0oooo0P00003g0?ooo`00:03oool00`000000oooo0?ooo`2:0?ooo`80
0000n@3oool002P0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`3i0?ooo`00:03o
ool00`000000oooo0?ooo`270?ooo`800000o03oool002P0oooo00<000000?ooo`3oool0Q@3oool2
00000?h0oooo000X0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0oP3oool002P0
oooo0`0000220?ooo`800000o`3oool20?ooo`00:03oool00`000000oooo0?ooo`200?ooo`800000
o`3oool40?ooo`00:03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0?l0oooo103o
ool002P0oooo00<000000?ooo`3oool0O@3oool200000?l0oooo1`3oool002P0oooo00<000000?oo
o`3oool0N`3oool200000?l0oooo2@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo000X0?ooo`030000003oool0oooo07P0oooo0P00003o0?ooo``0oooo
000X0?ooo`<00000M`3oool00`000000oooo0?ooo`3o0?ooo``0oooo000X0?ooo`030000003oool0
oooo07D0oooo0P00003o0?ooo`l0oooo000X0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool0o`3oool?0?ooo`0000<0oooo000000000000100000040?ooo`@000001@3oool4000000D0
oooo100000070?ooo`030000003oool0oooo0780oooo0P00003o0?oooa80oooo00000`3oool00000
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?oooa80oooo00020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0K`3o
ool200000?l0oooo5@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool0103oool4000006d0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06`0oooo0P00003o0?oooaP0oooo00050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00000`3oool000000?ooo`030?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool200000?l0oooo6`3o
ool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1W0?ooo`800000o`3ooolM0?ooo`000P3oool4000000D0oooo
100000050?ooo`@000001@3oool4000000L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`3o0?oooad0oooo000X0?ooo`030000003oool0oooo06@0oooo0P00003o0?ooob00oooo000X
0?ooo`<00000HP3oool200000?l0oooo8P3oool002P0oooo00<000000?ooo`3oool0H03oool20000
0?l0oooo903oool002P0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3o0?ooob@0
oooo000X0?ooo`030000003oool0oooo05d0oooo0P00003o0?ooobL0oooo000X0?ooo`030000003o
ool0oooo05/0oooo0P00003o0?ooobT0oooo000X0?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool0o`3ooolY0?ooo`00:03oool00`000000oooo0?ooo`1H0?ooo`800000o`3oool/0?oo
o`00:03oool3000005L0oooo00<000000?ooo`3oool0o`3oool/0?ooo`00:03oool00`000000oooo
0?ooo`1E0?ooo`800000o`3oool_0?ooo`00:03oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0?l0oooo;`3oool002P0oooo00<000000?ooo`3oool0DP3oool200000?l0oooo<P3oool0
02P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?oooc80oooo000X0?ooo`03
0000003oool0oooo04l0oooo0P00003o0?ooocD0oooo000X0?ooo`<00000CP3oool00`000000oooo
0?ooo`3o0?ooocD0oooo000X0?ooo`030000003oool0oooo04`0oooo0P00003o0?ooocP0oooo000X
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`00:03oool00`00
0000oooo0?ooo`190?ooo`800000o`3ooolk0?ooo`00:03oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo0?l0oooo>`3oool002P0oooo00<000000?ooo`3oool0AP3oool200000?l0oooo
?P3oool002P0oooo00<000000?ooo`3oool0A03oool200000?l0oooo@03oool002P0oooo0`000013
0?ooo`030000003oool0oooo0?l0oooo@03oool002P0oooo00<000000?ooo`3oool0@@3oool20000
0?l0oooo@`3oool002P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3o0?oood<0
oooo00000`3oool0000000000004000000<0oooo1P0000040?ooo`@000001@3oool4000000L0oooo
00<000000?ooo`3oool0?P3oool200000?l0ooooAP3oool000030?ooo`000000oooo00<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0l0?oo
o`800000o`3ooom80?ooo`000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`3o0?ooodP0oooo00030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0i0?ooo`800000o`3ooom;0?ooo`00103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00@0oooo1000000g0?ooo`030000003oool0oooo0?l0ooooB`3oool000D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`@00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool200000?l0
ooooCP3oool000030?ooo`000000oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?ooodh0
oooo00000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03<0oooo0P00003o0?oooe40oooo00020?ooo`@00000
1@3oool4000000D0oooo1@0000040?ooo`@000001`3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0?l0ooooD@3oool002P0oooo00<000000?ooo`3oool0<03oool200000?l0ooooE03o
ool002P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooe@0oooo000X0?oo
o`<00000;@3oool200000?l0ooooE`3oool002P0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3o0?oooeL0oooo000X0?ooo`030000003oool0oooo02X0oooo0P00003o0?oooeX0oooo
000X0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`00:03oool0
0`000000oooo0?ooo`0W0?ooo`800000o`3ooomM0?ooo`00:03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0?l0ooooG@3oool002P0oooo0`00000T0?ooo`800000o`3ooomP0?ooo`00
:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooH03oool002P0oooo00<0
00000?ooo`3oool08@3oool200000?l0ooooH`3oool002P0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`3o0?ooof<0oooo000X0?ooo`030000003oool0oooo01h0oooo0P00003o0?oo
ofH0oooo000X0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00
:03oool00`000000oooo0?ooo`0K0?ooo`800000o`3ooomY0?ooo`00:03oool3000001X0oooo00<0
00000?ooo`3oool0o`3ooomY0?ooo`00:03oool00`000000oooo0?ooo`0H0?ooo`800000o`3ooom/
0?ooo`00:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooK03oool002P0
oooo00<000000?ooo`3oool05@3oool200000?l0ooooK`3oool002P0oooo00<000000?ooo`3oool0
4`3oool200000?l0ooooL@3oool002P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3o0?ooog40oooo000X0?ooo`030000003oool0oooo0100oooo0P00003o0?ooog@0oooo000X0?oo
o`<000003`3oool00`000000oooo0?ooo`3o0?ooog@0oooo000X0?ooo`030000003oool0oooo00d0
oooo0P00003o0?ooogL0oooo000X0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
o`3ooomg0?ooo`0000<0oooo000000000000100000040?ooo`@000001@3oool4000000D0oooo1000
00070?ooo`030000003oool0oooo00X0oooo0P00003o0?ooogX0oooo00000`3oool000000?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?ooogX0oooo00020?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0P00003o0?ooogd0oooo00030?ooo`03
0000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomm0?ooo`00103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103o
ool4000000<0oooo0P00003o0?oooh00oooo00050?ooo`030000003oool0oooo00<0oooo10000004
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooh00oooo0000
0`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`800000o`3ooon30?ooo`0000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`00003o0?ooohD0oooo00020?ooo`@000001@3oool5000000@0oooo100000050?ooo`@00000
1`3oool300000?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool3
00000?l0ooooQP3oool002P0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:03oool00`000000
oooo0?ooo`3o0?ooohH0oooo000X0?ooo`030000003oool0oooo0?l0ooooQP3oool002P0oooo00<0
00000?ooo`3oool0o`3ooon60?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00
o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{108, 395}, {730.563, 553.688}} -> {-0.0118373, 6879.35, \
0.000161456, 11.1704}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rendite-Polynom und Rendite", "Subsection"],

Cell["Das Rendite-Polynom der Zahlungsreihe:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(InterestRatePoly[c]\)[x]\)], "Input"],

Cell[BoxData[
    \(\(-1000\)\ \((\(-3\) + 38\ x + 56\ x\^2 + 20\ x\^3)\)\)], "Output"]
}, Open  ]],

Cell["Die Menge seiner reellen Nullstellen:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InterestRateRealZeros[c]\)], "Input"],

Cell[BoxData[
    \({0.07127113816771066`}\)], "Output"]
}, Open  ]],

Cell["\<\
Interne Zinsrate (Rendite) als Nullstelle des Rendite-Polynoms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InternalRate[c]\)], "Input"],

Cell[BoxData[
    \(0.07127113816771047`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Eindeutige Existenz des internen Zinssatzes", "Subsection"],

Cell[TextData[{
  "Eine Zahlungsreihe ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0, c\_1, \[Ellipsis], c\_n\)]],
  " mit positiver Nettosumme ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0 + c\_1 + \[Ellipsis] + c\_n\)]],
  " besitzt eine eindeutig bestimmte Rendite, wenn der \"transformierte \
Zahlungsstrom\" ",
  Cell[BoxData[
      \(TraditionalForm\`c\&~\_0, c\&~\_1, \[Ellipsis], c\&~\_n\)]],
  " mit ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\&~\_k\), ":=", 
          RowBox[{\(\[Sum]\+\(j = 0\)\%k\), 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {\(n - j\)},
                    {\(k - j\)}
                    }], ")"}], \(c\_j\)}]}]}], TraditionalForm]]],
  " genau einen Vorzeichenwechsel aufweist (",
  StyleBox["hinreichendes",
    FontVariations->{"Underline"->True}],
  " Kriterium; vgl. P. Bender: Der interne Zinssatz bei beliebigen \
Investitionen, Preprint Universit\[ADoubleDot]t Paderborn, 1990):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(PositiveInvestmentQ[{\(-100\), 20, \(-50\), 70, 
        80}]\)\)\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PositiveInvestmentQ[{1, 4, \(-7\), 6, 1, \(-1\)}]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Entscheidungsmethoden", "Section"],

Cell[CellGroupData[{

Cell["Vier Hilfsfunktionen", "Subsection"],

Cell[TextData[{
  "Optimismus-Parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] \[Element] \([0; 1]\)\)]],
  " f\[UDoubleDot]r das Hurwicz-Verfahren:"
}], "Text"],

Cell[BoxData[
    \(\(lambda = 0.5;\)\)], "Input"],

Cell["\<\
Die Wertfunktion nach Hurwicz, angewandt auf einen Vektor von Nutzenwerten:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(HurwiczValue[{\(-3\), 0, 7, 4, 2}, lambda]\)\)\)], "Input"],

Cell[BoxData[
    \(2.`\)], "Output"]
}, Open  ]],

Cell["\<\
Gew\[ODoubleDot]hnlicher Erwartungswert (Summe 1 der \
Wahrscheinlichkeitsverteilung wird \[UDoubleDot]berpr\[UDoubleDot]ft):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expectation[{1, 2, 3, 4, 5, 6}, {0.1, 0.1, 0.2, 0.1, 0.2, 
        0.3}]\)], "Input"],

Cell[BoxData[
    \(4.1`\)], "Output"]
}, Open  ]],

Cell["\<\
Nutzenerwartungswert bei gegebener Nutzenfunktion \
(\[CapitalUDoubleDot]bergabe als reine Funktion) sowie \
Wahrscheinlichkeitsverteilung prob (Summe 1 wird \[UDoubleDot]berpr\
\[UDoubleDot]ft):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(prob = {0.1, 0.15, 0.15, 0.3, 0.2, 
          0.1};\)\ \), "\[IndentingNewLine]", 
    \(ExpectedUtility[
      LogUtility[1, 1, Normalize \[Rule] {1, 100}], {1, 2, 3, 4, 5, 6}, 
      prob]\)}], "Input"],

Cell[BoxData[
    \(0.25747490543075163`\)], "Output"]
}, Open  ]],

Cell["Noch einmal das Beispiel aus Abschnitt 1:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cmat // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "15000", "15000", "15000", "15000", "15000"},
            {\(-20000\), \(-5000\), "10000", "25000", "25000", "25000"},
            {\(-40000\), \(-25000\), \(-10000\), "5000", "20000", "35000"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Die resultierende Matrix der \"Bedauernswerte\" (nach L. Savage):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RegretMatrix[cmat] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", \(-10000\), \(-10000\), \(-20000\)},
            {\(-20000\), \(-20000\), \(-5000\), "0", "0", \(-10000\)},
            {\(-40000\), \(-40000\), \(-25000\), \(-20000\), \(-5000\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entscheidungen bei \"v\[ODoubleDot]lligem Nichtwissen\"", "Subsection"],

Cell[TextData[{
  "Die L\[ODoubleDot]sungsmenge nach dem Maximin-Verfahren (entspricht \
Hurwicz mit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 0\)]],
  "). Ausgegeben werden die Indizes der Alternativen (bzw. Strategien):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaximinSolve[cmat]\)], "Input"],

Cell[BoxData[
    \({1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die L\[ODoubleDot]sungsmenge nach dem Maximax-Verfahren (entspricht \
Hurwicz mit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1\)]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaximaxSolve[cmat]\)], "Input"],

Cell[BoxData[
    \({3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die L\[ODoubleDot]sungsmenge nach der Hurwicz-Methode mit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 0.7\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HurwiczSolve[cmat, 0.7]\)], "Input"],

Cell[BoxData[
    \({3}\)], "Output"]
}, Open  ]],

Cell["Die L\[ODoubleDot]sungsmenge nach der Savage-Methode:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SavageSolve[cmat]\)], "Input"],

Cell[BoxData[
    \({1, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Die L\[ODoubleDot]sungsmenge nach der Laplace-Methode (implizite Annahme von \
Gleichwahrscheinlichkeit der zur Auswahl stehenden Alternativen):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LaplaceSolve[cmat]\)], "Input"],

Cell[BoxData[
    \({1}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entscheidungen bei Risiko", "Subsection"],

Cell["\<\
Die L\[ODoubleDot]sungsmenge nach dem Bernoulli-Verfahren (explizite \
Einbeziehung von Wahrscheinlichkeiten f\[UDoubleDot]r die Umweltbedingungen, \
siehe oben):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BernoulliSolve[cmat, prob]\)], "Input"],

Cell[BoxData[
    \({2}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Risikoanalyse", "Section"],

Cell[CellGroupData[{

Cell["Ausgangsdaten einer Lotterie (Beispiel)", "Subsection"],

Cell["Die Wahrscheinlichkeitsverteilung der Lotterie:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prob = {1/10^5, 1/10^4, 1/10^3, 1 - \((1/10^5 + 1/10^4 + 1/10^3)\)} // 
        N\)], "Input"],

Cell[BoxData[
    \({0.00001`, 0.0001`, 0.001`, 0.99889`}\)], "Output"]
}, Open  ]],

Cell["\<\
Die m\[ODoubleDot]glichen Reingewinne beim 1., 2., 3. Preis und Nicht-Gewinn \
(Lospreis 5 Euro):\
\>", "Text"],

Cell[BoxData[
    \(\(c = {22500 - 5, 6000 - 5, 100 - 5, 0 - 5};\)\)], "Input"],

Cell["Die Nutzenfunktion des Lotterie-Spielers Timo:", "Text"],

Cell[BoxData[
    \(uTimo[x_] := \((x + 5)\)^\((3/2)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[uTimo[x], {x, \(-5\), 22500}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0240211 4.23186e-005 0.0147151 1.74343e-007 [
[.23561 .00222 -12 -9 ]
[.23561 .00222 12 0 ]
[.44721 .00222 -15 -9 ]
[.44721 .00222 15 0 ]
[.6588 .00222 -15 -9 ]
[.6588 .00222 15 0 ]
[.87039 .00222 -15 -9 ]
[.87039 .00222 15 0 ]
[.01152 .10189 -36 -4.5 ]
[.01152 .10189 0 4.5 ]
[.01152 .18906 -28.5 -6.25 ]
[.01152 .18906 0 6.25 ]
[.01152 .27623 -40.5 -6.25 ]
[.01152 .27623 0 6.25 ]
[.01152 .3634 -28.5 -6.25 ]
[.01152 .3634 0 6.25 ]
[.01152 .45057 -40.5 -6.25 ]
[.01152 .45057 0 6.25 ]
[.01152 .53774 -28.5 -6.25 ]
[.01152 .53774 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23561 .01472 m
.23561 .02097 L
s
[(5000)] .23561 .00222 0 1 Mshowa
.44721 .01472 m
.44721 .02097 L
s
[(10000)] .44721 .00222 0 1 Mshowa
.6588 .01472 m
.6588 .02097 L
s
[(15000)] .6588 .00222 0 1 Mshowa
.87039 .01472 m
.87039 .02097 L
s
[(20000)] .87039 .00222 0 1 Mshowa
.125 Mabswid
.06634 .01472 m
.06634 .01847 L
s
.10866 .01472 m
.10866 .01847 L
s
.15098 .01472 m
.15098 .01847 L
s
.1933 .01472 m
.1933 .01847 L
s
.27793 .01472 m
.27793 .01847 L
s
.32025 .01472 m
.32025 .01847 L
s
.36257 .01472 m
.36257 .01847 L
s
.40489 .01472 m
.40489 .01847 L
s
.48953 .01472 m
.48953 .01847 L
s
.53184 .01472 m
.53184 .01847 L
s
.57416 .01472 m
.57416 .01847 L
s
.61648 .01472 m
.61648 .01847 L
s
.70112 .01472 m
.70112 .01847 L
s
.74344 .01472 m
.74344 .01847 L
s
.78576 .01472 m
.78576 .01847 L
s
.82808 .01472 m
.82808 .01847 L
s
.91271 .01472 m
.91271 .01847 L
s
.95503 .01472 m
.95503 .01847 L
s
.99735 .01472 m
.99735 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02402 .10189 m
.03027 .10189 L
s
[(500000)] .01152 .10189 1 0 Mshowa
.02402 .18906 m
.03027 .18906 L
s
gsave
.01152 .18906 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02402 .27623 m
.03027 .27623 L
s
gsave
.01152 .27623 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02402 .3634 m
.03027 .3634 L
s
gsave
.01152 .3634 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02402 .45057 m
.03027 .45057 L
s
gsave
.01152 .45057 -40.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02402 .53774 m
.03027 .53774 L
s
gsave
.01152 .53774 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.02402 .03215 m
.02777 .03215 L
s
.02402 .04958 m
.02777 .04958 L
s
.02402 .06702 m
.02777 .06702 L
s
.02402 .08445 m
.02777 .08445 L
s
.02402 .11932 m
.02777 .11932 L
s
.02402 .13676 m
.02777 .13676 L
s
.02402 .15419 m
.02777 .15419 L
s
.02402 .17162 m
.02777 .17162 L
s
.02402 .20649 m
.02777 .20649 L
s
.02402 .22393 m
.02777 .22393 L
s
.02402 .24136 m
.02777 .24136 L
s
.02402 .2588 m
.02777 .2588 L
s
.02402 .29366 m
.02777 .29366 L
s
.02402 .3111 m
.02777 .3111 L
s
.02402 .32853 m
.02777 .32853 L
s
.02402 .34597 m
.02777 .34597 L
s
.02402 .38084 m
.02777 .38084 L
s
.02402 .39827 m
.02777 .39827 L
s
.02402 .4157 m
.02777 .4157 L
s
.02402 .43314 m
.02777 .43314 L
s
.02402 .46801 m
.02777 .46801 L
s
.02402 .48544 m
.02777 .48544 L
s
.02402 .50288 m
.02777 .50288 L
s
.02402 .52031 m
.02777 .52031 L
s
.02402 .55518 m
.02777 .55518 L
s
.02402 .57261 m
.02777 .57261 L
s
.02402 .59005 m
.02777 .59005 L
s
.02402 .60748 m
.02777 .60748 L
s
.25 Mabswid
.02402 0 m
.02402 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01474 L
.02605 .01478 L
.02846 .01492 L
.03279 .01525 L
.03784 .01577 L
.04262 .01635 L
.06244 .01952 L
.08265 .02375 L
.10458 .02925 L
.14545 .04158 L
.1848 .05562 L
.22263 .07086 L
.26292 .08876 L
.30169 .10748 L
.34292 .12887 L
.38262 .15083 L
.42082 .17313 L
.46146 .19807 L
.50059 .22321 L
.54217 .25107 L
.58224 .27899 L
.62079 .30683 L
.6618 .33743 L
.70128 .36785 L
.73925 .39796 L
.77968 .43089 L
.81859 .46344 L
.85995 .49892 L
.89979 .53394 L
.93812 .56838 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00P03oool4000000D0oooo100000050?ooo`@000001@3oool4000002/0
oooo1`0000030?ooo`@000001@3oool4000000D0oooo100000050?ooo`@000009P3oool7000000<0
oooo100000050?ooo`@000001@3oool4000000D0oooo1000000V0?ooo`H00000103oool4000000D0
oooo100000050?ooo`@000001@3oool4000001l0oooo001o0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0L
0?ooo`00Q03oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0703oool008@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo01`0oooo00240?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
203oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0L0?ooo`00P03oool4000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0103oool4000000@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01`0oooo
00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo01`0oooo00200?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo02T0oooo0`0000050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool0903oool3000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`0L0?ooo`00P03oool5000000@0oooo100000050?ooo`@000001@3oool4000002h0oooo00<0
00000?ooo`3oool0103oool4000000D0oooo100000050?ooo`@000001@3oool4000002T0oooo00<0
00000?ooo`3oool0103oool5000000@0oooo100000050?ooo`@000001@3oool4000002L0oooo1000
00050?ooo`@000001@3oool4000000D0oooo100000050?ooo`@000007`3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00440oooo00<000000?ooo`3oool0o`3ooom]0?ooo`00@@3oool00`000000oooo
0?ooo`3o0?ooofd0oooo00110?ooo`030000003oool0oooo0?l0ooooK@3oool00440oooo00<00000
0?ooo`3oool0o`3ooom]0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooofd0oooo00110?ooo`03
0000003oool0oooo0?l0ooooK@3oool003P0ooooo`00001i00000000@@3oool00`000000oooo0?oo
o`080?ooo`H000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool100000040oooo00110?ooo`030000003oool0oooo00d0oooo1000000k
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo02l0oooo00110?ooo`030000003oool0oooo0140oooo1000003o0?oo
oeP0oooo00110?ooo`030000003oool0oooo01D0oooo1000003o0?oooe@0oooo00110?ooo`030000
003oool0oooo01T0oooo1000003o0?oooe00oooo00110?ooo`8000007P3oool300000?l0ooooC@3o
ool00440oooo00<000000?ooo`3oool0803oool300000?l0ooooBP3oool00440oooo00<000000?oo
o`3oool08`3oool300000?l0ooooA`3oool00440oooo00<000000?ooo`3oool09P3oool300000?l0
ooooA03oool00440oooo00<000000?ooo`3oool0:@3oool300000?l0oooo@@3oool00440oooo00<0
00000?ooo`3oool0;03oool300000?l0oooo?P3oool00440oooo00<000000?ooo`3oool0;`3oool3
00000?l0oooo>`3oool00440oooo0P00000c0?ooo`<00000o`3ooolh0?ooo`00@@3oool00`000000
oooo0?ooo`0e0?ooo`<00000o`3ooole0?ooo`00@@3oool00`000000oooo0?ooo`0h0?ooo`<00000
o`3ooolb0?ooo`00@@3oool00`000000oooo0?ooo`0k0?ooo`800000o`3oool`0?ooo`00@@3oool0
0`000000oooo0?ooo`0m0?ooo`800000o`3oool^0?ooo`00@@3oool00`000000oooo0?ooo`0o0?oo
o`<00000o`3oool[0?ooo`00@@3oool2000004<0oooo0P00003o0?ooobT0oooo00110?ooo`030000
003oool0oooo04@0oooo0P00003o0?ooobL0oooo00110?ooo`030000003oool0oooo04H0oooo0`00
003o0?ooob@0oooo00110?ooo`030000003oool0oooo04T0oooo0P00003o0?ooob80oooo00110?oo
o`030000003oool0oooo04/0oooo0`00003o0?oooal0oooo00110?ooo`030000003oool0oooo04h0
oooo0P00003o0?oooad0oooo00110?ooo`030000003oool0oooo0500oooo0`00003o0?oooaX0oooo
00110?ooo`800000E03oool200000?l0oooo603oool00440oooo00<000000?ooo`3oool0E@3oool3
00000?l0oooo5@3oool00440oooo00<000000?ooo`3oool0F03oool200000?l0oooo4`3oool000P0
oooo100000050?ooo`@000001@3oool4000000D0oooo100000050?ooo`@000001@3oool4000000P0
oooo00<000000?ooo`3oool0FP3oool200000?l0oooo4@3oool000L0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
G03oool200000?l0oooo3`3oool000`0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05h0oooo0P00003o0?ooo`d0oooo000<0?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool01@3oool300000600oooo0P00003o0?ooo`/0oooo000<0?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1R0?oo
o`800000o`3oool90?ooo`00203oool4000000@0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1T0?ooo`800000o`3oool70?ooo`00203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`050000
003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0IP3oool2
00000?l0oooo1@3oool000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo0P00003o0?ooo`<0oooo00080?ooo`D00000
103oool4000000D0oooo100000050?ooo`@000001@3oool4000000D0oooo100000080?ooo`030000
003oool0oooo06X0oooo0P00003o0?ooo`40oooo00110?ooo`030000003oool0oooo06`0oooo0P00
003n0?ooo`00@@3oool2000006l0oooo0P00003l0?ooo`00@@3oool00`000000oooo0?ooo`1`0?oo
o`800000nP3oool00440oooo00<000000?ooo`3oool0LP3oool200000?P0oooo00110?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0m@3oool00440oooo00<000000?ooo`3oool0M@3o
ool200000?D0oooo00110?ooo`030000003oool0oooo07L0oooo0P00003c0?ooo`00@@3oool20000
07X0oooo00<000000?ooo`3oool0l03oool00440oooo00<000000?ooo`3oool0NP3oool200000?00
oooo00110?ooo`030000003oool0oooo07`0oooo0P00003^0?ooo`00@@3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo0>/0oooo00110?ooo`030000003oool0oooo07l0oooo0P00003[
0?ooo`00@@3oool00`000000oooo0?ooo`210?ooo`800000j@3oool00440oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`3V0?ooo`00@@3oool2000008D0oooo0P00003V0?ooo`00@@3o
ool00`000000oooo0?ooo`260?ooo`800000i03oool00440oooo00<000000?ooo`3oool0R03oool2
00000>80oooo00110?ooo`030000003oool0oooo08X0oooo0P00003P0?ooo`00@@3oool00`000000
oooo0?ooo`2<0?ooo`800000gP3oool00440oooo00<000000?ooo`3oool0SP3oool200000=`0oooo
00110?ooo`800000T@3oool200000=X0oooo00110?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0e`3oool001<0oooo1`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool7000000<0oooo1000000;0?ooo`030000003oool0oooo09<0oooo0P00003G0?oo
o`005P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`2E0?ooo`800000e@3oool001H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0dP3oool001H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09P0oooo
0P00003B0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0VP3oool200000=00oooo000F0?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`<00000W03oool00`000000oooo0?ooo`3=0?ooo`005P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2M0?ooo`800000c@3oool001@0oooo0`00000B0?ooo`<000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`030000003oool0oooo
09l0oooo0P00003;0?ooo`005P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2Q0?oo
o`030000003oool0oooo0<P0oooo000j0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`2R0?ooo`800000b03oool003X0oooo100000030?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0a@3oool003X0oooo00<000000?ooo`3oool0103oool200000:H0oooo
00<000000?ooo`3oool0a03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2V0?ooo`800000a03oool003`0oooo0`0000020?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool0`@3oool00440oooo00<000000?ooo`3oool0Z@3oool200000<40oooo00110?ooo`03
0000003oool0oooo0:/0oooo00<000000?ooo`3oool0_P3oool00440oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`2m0?ooo`00@@3oool00`000000oooo0?ooo`2]0?ooo`800000_@3o
ool00440oooo0P00002`0?ooo`030000003oool0oooo0;X0oooo00110?ooo`030000003oool0oooo
0;00oooo0P00002j0?ooo`00@@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0;L0
oooo00110?ooo`030000003oool0oooo0;<0oooo0P00002g0?ooo`00@@3oool00`000000oooo0?oo
o`2e0?ooo`800000]@3oool00440oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`2b
0?ooo`00@@3oool00`000000oooo0?ooo`2h0?ooo`800000/P3oool00440oooo0P00002k0?ooo`03
0000003oool0oooo0:l0oooo00110?ooo`030000003oool0oooo0;/0oooo0P00002_0?ooo`00@@3o
ool00`000000oooo0?ooo`2m0?ooo`800000[@3oool00440oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`2Z0?ooo`00@@3oool00`000000oooo0?ooo`300?ooo`800000ZP3oool00440
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`2W0?ooo`00@@3oool200000<@0oooo
00<000000?ooo`3oool0YP3oool000030?ooo`000000000000D00000103oool2000000H0oooo1000
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool7000000<0oooo1000
000;0?ooo`030000003oool0oooo0<@0oooo0P00002V0?ooo`00103oool00`000000oooo0?ooo`05
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0X`3o
ool000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`2R0?ooo`00103oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`380?ooo`800000XP3oool000@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0bP3oool00`000000
oooo0?ooo`2O0?ooo`00103oool00`000000oooo0?ooo`0=0?ooo`@000001@3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`2N0?ooo`00
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`<00000c03oool2000009h0oooo00020?ooo`<000003`3o
ool00`000000oooo0?ooo`0B0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`2K0?ooo`00103oool0
0`000000oooo0?ooo`0=0?ooo`D000004P3oool00`000000oooo0?ooo`040?ooo`@000001@3oool3
000000<0oooo00<000000?ooo`3oool0c`3oool2000009/0oooo000j0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo09P0oooo000j0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo09L0oooo000j0?ooo`@000000`3oool00`000000oooo0?ooo`3C0?ooo`800000U`3oool003X0
oooo00<000000?ooo`3oool0103oool200000=H0oooo00<000000?ooo`3oool0U03oool003/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3F0?ooo`800000U03oool003`0oooo0`00
00020?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0T@3oool00440oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo0?ooo`2@0?ooo`00@@3oool00`000000oooo0?ooo`3J0?oo
o`800000T03oool00440oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`2=0?ooo`00
@@3oool00`000000oooo0?ooo`3M0?ooo`030000003oool0oooo08`0oooo00110?ooo`800000g`3o
ool2000008`0oooo00110?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool0R@3oool0
0440oooo00<000000?ooo`3oool0h@3oool00`000000oooo0?ooo`280?ooo`00@@3oool00`000000
oooo0?ooo`3R0?ooo`800000R03oool00440oooo00<000000?ooo`3oool0i03oool00`000000oooo
0?ooo`250?ooo`00@@3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo08@0oooo0011
0?ooo`800000i`3oool2000008@0oooo00110?ooo`030000003oool0oooo0>P0oooo00<000000?oo
o`3oool0P@3oool00440oooo00<000000?ooo`3oool0j@3oool00`000000oooo0?ooo`200?ooo`00
@@3oool00`000000oooo0?ooo`3Z0?ooo`800000P03oool00440oooo00<000000?ooo`3oool0k03o
ool00`000000oooo0?ooo`1m0?ooo`00@@3oool00`000000oooo0?ooo`3]0?ooo`800000O@3oool0
0440oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`1j0?ooo`00@@3oool200000?40
oooo00<000000?ooo`3oool0N@3oool001<0oooo1P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool7000000<0oooo1000000;0?ooo`030000003oool0oooo0?40oooo
0P00001i0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?<0oooo00<000000?ooo`3oool0
MP3oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?@0oooo00<000000?ooo`3oool0M@3oool001D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?D0oooo0P00001e0?ooo`005P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0m`3oool00`00
0000oooo0?ooo`1b0?ooo`005`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool300000?P0oooo00<000000?ooo`3oool0L@3oool001<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3i0?ooo`800000L@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0>0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0n`3oool00`000000oooo0?ooo`1^0?ooo`00503oool4000001<0oooo
00<000000?ooo`3oool0103oool4000000D0oooo0`0000030?ooo`030000003oool0oooo0?`0oooo
00<000000?ooo`3oool0K@3oool003X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0?d0oooo0P00001]0?ooo`00>P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0o`3oool00`000000oooo0?ooo`1Z0?ooo`00>P3oool4000000<0oooo00<0
00000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo06T0oooo000j0?ooo`030000003oool0
oooo00@0oooo0P00003o0?ooo`<0oooo00<000000?ooo`3oool0J03oool003/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo0P00001X0?ooo`00?03oool300000080
oooo00<000000?ooo`3oool0o`3oool50?ooo`030000003oool0oooo06D0oooo00110?ooo`030000
003oool0oooo0?l0oooo1P3oool00`000000oooo0?ooo`1T0?ooo`00@@3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo0P00001T0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<00000
0?ooo`3oool0H@3oool00440oooo0P00003o0?ooo`/0oooo00<000000?ooo`3oool0H03oool00440
oooo00<000000?ooo`3oool0o`3oool;0?ooo`030000003oool0oooo05l0oooo00110?ooo`030000
003oool0oooo0?l0oooo303oool00`000000oooo0?ooo`1N0?ooo`00@@3oool00`000000oooo0?oo
o`3o0?ooo`d0oooo0P00001N0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo00<00000
0?ooo`3oool0F`3oool00440oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
05X0oooo00110?ooo`030000003oool0oooo0?l0oooo4@3oool00`000000oooo0?ooo`1I0?ooo`00
@@3oool200000?l0oooo4`3oool00`000000oooo0?ooo`1H0?ooo`00@@3oool00`000000oooo0?oo
o`3o0?oooa<0oooo00<000000?ooo`3oool0E`3oool00440oooo00<000000?ooo`3oool0o`3ooolD
0?ooo`030000003oool0oooo05H0oooo00110?ooo`030000003oool0oooo0?l0oooo5@3oool20000
05H0oooo00110?ooo`030000003oool0oooo0?l0oooo5`3oool00`000000oooo0?ooo`1C0?ooo`00
@@3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool0DP3oool00440oooo0P00
003o0?oooaX0oooo00<000000?ooo`3oool0D@3oool00440oooo00<000000?ooo`3oool0o`3ooolJ
0?ooo`030000003oool0oooo0500oooo00000`3oool0000000000004000000D0oooo0P0000060?oo
o`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo1`0000030?oo
o`@000002`3oool00`000000oooo0?ooo`3o0?oooa/0oooo0P00001@0?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo7@3oool00`000000oooo0?ooo`1=0?ooo`000P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooah0
oooo00<000000?ooo`3oool0C03oool000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`030000
003oool0oooo04/0oooo00040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo803oool2000004/0oooo0005
0?ooo`030000003oool0oooo00`0oooo100000050?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool300000?l0oooo8P3oool00`000000oooo0?ooo`180?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo8`3oool00`000000oooo0?ooo`17
0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0180oooo0`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool30000
00<0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`030000003oool0oooo04H0oooo00020?ooo`@0
00003P3oool500000180oooo00<000000?ooo`3oool0103oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0?l0oooo9@3oool2000004H0oooo000j0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?ooobL0oooo00<000000?oo
o`3oool0@`3oool003X0oooo100000030?ooo`030000003oool0oooo0?l0oooo:03oool00`000000
oooo0?ooo`120?ooo`00>P3oool00`000000oooo0?ooo`040?ooo`800000o`3ooolZ0?ooo`030000
003oool0oooo0440oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oolZ0?ooo`030000003oool0oooo0400oooo000l0?ooo`<000000P3oool00`000000oooo0?ooo`3o
0?ooob/0oooo0P0000100?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?oo
o`3oool0?@3oool00440oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo03`0
oooo00110?ooo`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0k0?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?oooc00oooo00<000000?ooo`3oool0>P3oool00440oooo0P00003o
0?oooc80oooo00<000000?ooo`3oool0>@3oool00440oooo00<000000?ooo`3oool0o`3ooolb0?oo
o`030000003oool0oooo03P0oooo00110?ooo`030000003oool0oooo0?l0oooo<`3oool2000003P0
oooo00110?ooo`030000003oool0oooo0?l0oooo=@3oool00`000000oooo0?ooo`0e0?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0=03oool00440oooo00<00000
0?ooo`3oool0o`3ooolg0?ooo`030000003oool0oooo03<0oooo00110?ooo`030000003oool0oooo
0?l0oooo>03oool00`000000oooo0?ooo`0b0?ooo`00@@3oool200000?l0oooo>P3oool00`000000
oooo0?ooo`0a0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooocX0oooo0P00000a0?ooo`00@@3o
ool00`000000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool0;P3oool00440oooo00<00000
0?ooo`3oool0o`3ooolm0?ooo`030000003oool0oooo02d0oooo00110?ooo`030000003oool0oooo
0?l0oooo?P3oool00`000000oooo0?ooo`0/0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooocl0
oooo00<000000?ooo`3oool0:`3oool00440oooo0P00003o0?oood40oooo00<000000?ooo`3oool0
:P3oool001@0oooo100000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool7000000<0oooo1000000;0?ooo`030000003oool0oooo0?l0oooo@@3oool00`000000oooo0?oo
o`0Y0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo@P3oool2000002T0oooo000H
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?oood@0oooo00<000000?ooo`3oool09P3oool001P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooA@3oool00`000000oooo0?ooo`0U0?oo
o`005P3oool2000000H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooodH0
oooo00<000000?ooo`3oool0903oool001P0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom70?ooo`030000003oool0oooo02<0
oooo000H0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<0
0000o`3ooom80?ooo`030000003oool0oooo0280oooo000C0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool3000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0Q0?ooo`00503o
ool4000001<0oooo00<000000?ooo`3oool0103oool4000000D0oooo0`0000030?ooo`030000003o
ool0oooo0?l0ooooBP3oool00`000000oooo0?ooo`0P0?ooo`00>P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo01l0oooo000j
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3o0?oood`0oooo00<0
00000?ooo`3oool07P3oool003X0oooo100000030?ooo`030000003oool0oooo0?l0ooooC@3oool2
000001h0oooo000j0?ooo`030000003oool0oooo00@0oooo0P00003o0?oooe00oooo00<000000?oo
o`3oool06`3oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooe00
oooo00<000000?ooo`3oool06P3oool003`0oooo0`0000020?ooo`030000003oool0oooo0?l0oooo
D@3oool00`000000oooo0?ooo`0I0?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooe80oooo00<0
00000?ooo`3oool0603oool00440oooo00<000000?ooo`3oool0o`3ooomC0?ooo`030000003oool0
oooo01L0oooo00110?ooo`030000003oool0oooo0?l0ooooE03oool00`000000oooo0?ooo`0F0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?oooeD0oooo00<000000?ooo`3oool05@3oool00440oooo
0P00003o0?oooeL0oooo00<000000?ooo`3oool0503oool00440oooo00<000000?ooo`3oool0o`3o
oomG0?ooo`800000503oool00440oooo00<000000?ooo`3oool0o`3ooomI0?ooo`030000003oool0
oooo0140oooo00110?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`0@0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?oooe/0oooo00<000000?ooo`3oool03`3oool00440oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`030000003oool0oooo00h0oooo00110?ooo`800000o`3o
oomN0?ooo`030000003oool0oooo00d0oooo00110?ooo`030000003oool0oooo0?l0ooooGP3oool0
0`000000oooo0?ooo`0<0?ooo`00@@3oool00`000000oooo0?ooo`3o0?oooel0oooo0P00000<0?oo
o`00@@3oool00`000000oooo0?ooo`3o0?ooof40oooo00<000000?ooo`3oool02@3oool00440oooo
00<000000?ooo`3oool0o`3ooomR0?ooo`030000003oool0oooo00P0oooo00110?ooo`030000003o
ool0oooo0?l0ooooH`3oool00`000000oooo0?ooo`070?ooo`00@@3oool00`000000oooo0?ooo`3o
0?ooofd0oooo00110?ooo`800000o`3ooom^0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooofd0
oooo00110?ooo`030000003oool0oooo0?l0ooooK@3oool00440oooo00<000000?ooo`3oool0o`3o
oom]0?ooo`00@@3oool00`000000oooo0?ooo`3o0?ooofd0oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40
oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{108, 395}, {291.125, 114.188}} -> {-14367.3, \
2.18248*^06, 94.7598, 23001.2}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyse", "Subsection"],

Cell["\<\
Timo's Sicherheits\[ADoubleDot]quivalent f\[UDoubleDot]r die Teilnahme an der \
Lotterie:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CertaintyEquivalent[uTimo, {\(-5\), 22500}, c, prob]\)], "Input"],

Cell[BoxData[
    \(13.755529614821361`\)], "Output"]
}, Open  ]],

Cell["\<\
Die zugeh\[ODoubleDot]rige Risikopr\[ADoubleDot]mie, die zeigt, dass Timo \
risikofreudig ist:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RiskPremium[uTimo, {\(-5\), 22500}, c, prob]\)], "Input"],

Cell[BoxData[
    \(\(-17.83052961482136`\)\)], "Output"]
}, Open  ]],

Cell["\<\
Das absolute und das relative Risikoeinstellungsma\[SZ] (als Funktion nach \
Arrow und Pratt):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AbsoluteRiskFunction[uTimo]\)[x]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/\(2\ \((5 + x)\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RelativeRiskFunction[uTimo]\)[x]\)], "Input"],

Cell[BoxData[
    \(\(-\(x\/\(2\ \((5 + x)\)\)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Zweipersonenspiele", "Section"],

Cell[CellGroupData[{

Cell["Spielmatrix", "Subsection"],

Cell["\<\
Die Matrix-Normalform g (Auszahlungsmatrix) eines \
Zweipersonen-Nullsummenspiels:\
\>", "Text"],

Cell[BoxData[
    \(Clear[g]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = {{1, 1, \(-2\), \(-2\)}, {\(-1\), 2, \(-1\), 2}, {0, 2, 0, 
          2}}\)], "Input"],

Cell[BoxData[
    \({{1, 1, \(-2\), \(-2\)}, {\(-1\), 2, \(-1\), 2}, {0, 2, 0, 
        2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", \(-2\), \(-2\)},
            {\(-1\), "2", \(-1\), "2"},
            {"0", "2", "0", "2"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dominanz-Beziehungen", "Subsection"],

Cell["Strategie A2 wird dominiert (von Strategie A3):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReduceLines[g]\)], "Input"],

Cell[BoxData[
    \({{1, 1, \(-2\), \(-2\)}, {0, 2, 0, 2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", \(-2\), \(-2\)},
            {"0", "2", "0", "2"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Strategie B3 ist dominant (dominiert alle \[UDoubleDot]brigen Strategien von \
Spieler B):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReduceColumns[g]\)], "Input"],

Cell[BoxData[
    \({{\(-2\)}, {\(-1\)}, {0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\)},
            {\(-1\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wert des Spiels, Sattelpunktl\[ODoubleDot]sung", "Subsection"],

Cell["\<\
Kleinster Wert des Spiels und Maximin-Strategien (f\[UDoubleDot]r Spieler A):\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MaximinSet[g]\)], "Input"],

Cell[BoxData[
    \({0, {3}}\)], "Output"]
}, Open  ]],

Cell["Gr\[ODoubleDot]\[SZ]ter Wert und Minimax-Strategien (f\[UDoubleDot]r \
Spieler B):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimaxSet[g]\)], "Input"],

Cell[BoxData[
    \({0, {3}}\)], "Output"]
}, Open  ]],

Cell["\<\
Der Wert des Spiels und das Paar (hier existierender) optimaler \
Gleichgewichtsstrategien f\[UDoubleDot]r Spieler A und B:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SaddlepointSolution[g]\)], "Input"],

Cell[BoxData[
    \({0, {{3, 3}}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["L\[ODoubleDot]sung in gemischten Strategien", "Subsection"],

Cell["\<\
Ein einfaches Beispiel aus S. Vajda: Theorie der Spiele und \
Linearprogrammierung (Walter de Gruyter: Berlin 1962, S. 128):\
\>", "Text"],

Cell[BoxData[
    \(\(gvajda = {{4, 1, 3}, {2, 3, 4}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4", "1", "3"},
            {"2", "3", "4"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["\<\
Ausgabe von: Wert / optimale Strategie von A / optimale Strategie von B:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MixedStrategySolution[gvajda]\)], "Input"],

Cell[BoxData[
    \({5\/2, {1\/4, 3\/4}, {1\/2, 1\/2, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 936}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1272, 904},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 11},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 7},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->36,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 9},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->18],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    LineSpacing->{1, 5},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    Hyphenation->True,
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    Hyphenation->True,
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    Hyphenation->True,
    LineSpacing->{1, 7},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    GridBoxOptions->{RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {-1, 0}},
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.6, 0.749996, 0.899992]],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"],
    FontSize->16],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {3, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 211, 7, 140, "Title"],
Cell[1968, 60, 157, 3, 53, "SmallText"],
Cell[2128, 65, 110, 5, 63, "Text"],
Cell[2241, 72, 76, 1, 81, "Input"],

Cell[CellGroupData[{
Cell[2342, 77, 39, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[2406, 81, 41, 0, 103, "Subsection"],
Cell[2450, 83, 185, 4, 102, "Text"],
Cell[2638, 89, 232, 4, 149, "Input"],
Cell[2873, 95, 92, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[2990, 101, 122, 2, 115, "Input"],
Cell[3115, 105, 392, 8, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3556, 119, 32, 0, 103, "Subsection"],
Cell[3591, 121, 125, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[3741, 128, 85, 1, 81, "Input"],
Cell[3829, 131, 48, 1, 79, "Output"]
}, Open  ]],
Cell[3892, 135, 127, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[4044, 142, 55, 1, 81, "Input"],
Cell[4102, 145, 54, 1, 98, "Output"]
}, Open  ]],
Cell[4171, 149, 96, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[4292, 155, 58, 1, 81, "Input"],
Cell[4353, 158, 38, 1, 98, "Output"]
}, Open  ]],
Cell[4406, 162, 123, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[4554, 169, 121, 2, 115, "Input"],
Cell[4678, 173, 414, 10, 171, "Output"]
}, Open  ]],
Cell[5107, 186, 72, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[5204, 190, 133, 2, 115, "Input"],
Cell[5340, 194, 26920, 561, 279, 3799, 271, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[32275, 758, 106, 3, 63, "Text"],
Cell[32384, 763, 79, 1, 81, "Input"],

Cell[CellGroupData[{
Cell[32488, 768, 135, 2, 115, "Input"],
Cell[32626, 772, 106, 2, 110, "Output"],
Cell[32735, 776, 27535, 581, 279, 4130, 288, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60331, 1364, 38, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[60394, 1368, 55, 0, 103, "Subsection"],
Cell[60452, 1370, 122, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[60599, 1377, 88, 1, 81, "Input"],
Cell[60690, 1380, 47, 1, 98, "Output"]
}, Open  ]],
Cell[60752, 1384, 127, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[60904, 1391, 103, 2, 81, "Input"],
Cell[61010, 1395, 72, 1, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61119, 1401, 61, 1, 81, "Input"],
Cell[61183, 1404, 31384, 688, 279, 5089, 359, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[92582, 2095, 125, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[92732, 2102, 227, 4, 115, "Input"],
Cell[92962, 2108, 74, 1, 80, "Output"],
Cell[93039, 2111, 26033, 559, 279, 3761, 280, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[119087, 2673, 73, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[119185, 2677, 64, 1, 81, "Input"],
Cell[119252, 2680, 47, 1, 82, "Output"]
}, Open  ]],
Cell[119314, 2684, 84, 1, 63, "Text"],

Cell[CellGroupData[{
Cell[119423, 2689, 128, 2, 81, "Input"],
Cell[119554, 2693, 27590, 574, 279, 3899, 277, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[147159, 3270, 125, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[147309, 3277, 84, 1, 81, "Input"],
Cell[147396, 3280, 50, 1, 103, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[147495, 3287, 47, 0, 103, "Subsection"],
Cell[147545, 3289, 142, 3, 102, "Text"],
Cell[147690, 3294, 196, 3, 149, "Input"],

Cell[CellGroupData[{
Cell[147911, 3301, 66, 1, 81, "Input"],
Cell[147980, 3304, 41, 1, 98, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148082, 3312, 36, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[148143, 3316, 29, 0, 103, "Subsection"],
Cell[148175, 3318, 71, 0, 63, "Text"],
Cell[148249, 3320, 134, 2, 115, "Input"],

Cell[CellGroupData[{
Cell[148408, 3326, 52, 1, 81, "Input"],
Cell[148463, 3329, 52, 1, 79, "Output"]
}, Open  ]],
Cell[148530, 3333, 76, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[148631, 3337, 182, 3, 149, "Input"],
Cell[148816, 3342, 52, 1, 79, "Output"]
}, Open  ]],
Cell[148883, 3346, 70, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[148978, 3350, 65, 1, 81, "Input"],
Cell[149046, 3353, 31350, 618, 279, 3820, 274, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[180445, 3977, 49, 0, 103, "Subsection"],
Cell[180497, 3979, 54, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[180576, 3983, 59, 1, 81, "Input"],
Cell[180638, 3986, 87, 1, 80, "Output"]
}, Open  ]],
Cell[180740, 3990, 53, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[180818, 3994, 57, 1, 81, "Input"],
Cell[180878, 3997, 56, 1, 79, "Output"]
}, Open  ]],
Cell[180949, 4001, 87, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[181061, 4007, 48, 1, 81, "Input"],
Cell[181112, 4010, 54, 1, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[181215, 4017, 65, 0, 103, "Subsection"],
Cell[181283, 4019, 983, 26, 211, "Text"],

Cell[CellGroupData[{
Cell[182291, 4049, 108, 2, 81, "Input"],
Cell[182402, 4053, 38, 1, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182477, 4059, 82, 1, 81, "Input"],
Cell[182562, 4062, 39, 1, 79, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[182662, 4070, 43, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[182730, 4074, 42, 0, 103, "Subsection"],
Cell[182775, 4076, 176, 5, 63, "Text"],
Cell[182954, 4083, 50, 1, 81, "Input"],
Cell[183007, 4086, 99, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[183131, 4092, 89, 1, 81, "Input"],
Cell[183223, 4095, 37, 1, 79, "Output"]
}, Open  ]],
Cell[183275, 4099, 149, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[183449, 4106, 105, 2, 81, "Input"],
Cell[183557, 4110, 38, 1, 79, "Output"]
}, Open  ]],
Cell[183610, 4114, 219, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[183854, 4123, 227, 5, 149, "Input"],
Cell[184084, 4130, 54, 1, 79, "Output"]
}, Open  ]],
Cell[184153, 4134, 57, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[184235, 4138, 51, 1, 81, "Input"],
Cell[184289, 4141, 392, 8, 135, "Output"]
}, Open  ]],
Cell[184696, 4152, 89, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[184810, 4158, 65, 1, 81, "Input"],
Cell[184878, 4161, 393, 8, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[185320, 4175, 77, 0, 103, "Subsection"],
Cell[185400, 4177, 248, 6, 102, "Text"],

Cell[CellGroupData[{
Cell[185673, 4187, 51, 1, 81, "Input"],
Cell[185727, 4190, 37, 1, 79, "Output"]
}, Open  ]],
Cell[185779, 4194, 182, 6, 63, "Text"],

Cell[CellGroupData[{
Cell[185986, 4204, 51, 1, 81, "Input"],
Cell[186040, 4207, 37, 1, 79, "Output"]
}, Open  ]],
Cell[186092, 4211, 159, 5, 63, "Text"],

Cell[CellGroupData[{
Cell[186276, 4220, 56, 1, 81, "Input"],
Cell[186335, 4223, 37, 1, 79, "Output"]
}, Open  ]],
Cell[186387, 4227, 69, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[186481, 4231, 50, 1, 81, "Input"],
Cell[186534, 4234, 40, 1, 79, "Output"]
}, Open  ]],
Cell[186589, 4238, 168, 3, 102, "Text"],

Cell[CellGroupData[{
Cell[186782, 4245, 51, 1, 81, "Input"],
Cell[186836, 4248, 37, 1, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[186922, 4255, 47, 0, 103, "Subsection"],
Cell[186972, 4257, 186, 4, 102, "Text"],

Cell[CellGroupData[{
Cell[187183, 4265, 59, 1, 81, "Input"],
Cell[187245, 4268, 37, 1, 79, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[187343, 4276, 35, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[187403, 4280, 61, 0, 103, "Subsection"],
Cell[187467, 4282, 63, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[187555, 4286, 114, 2, 81, "Input"],
Cell[187672, 4290, 71, 1, 79, "Output"]
}, Open  ]],
Cell[187758, 4294, 121, 3, 63, "Text"],
Cell[187882, 4299, 79, 1, 81, "Input"],
Cell[187964, 4302, 62, 0, 63, "Text"],
Cell[188029, 4304, 67, 1, 81, "Input"],

Cell[CellGroupData[{
Cell[188121, 4309, 72, 1, 81, "Input"],
Cell[188196, 4312, 34566, 710, 279, 5264, 344, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[222811, 5028, 29, 0, 103, "Subsection"],
Cell[222843, 5030, 113, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[222981, 5037, 85, 1, 81, "Input"],
Cell[223069, 5040, 53, 1, 79, "Output"]
}, Open  ]],
Cell[223137, 5044, 118, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[223280, 5051, 77, 1, 81, "Input"],
Cell[223360, 5054, 57, 1, 79, "Output"]
}, Open  ]],
Cell[223432, 5058, 118, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[223575, 5065, 67, 1, 81, "Input"],
Cell[223645, 5068, 64, 1, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223746, 5074, 67, 1, 81, "Input"],
Cell[223816, 5077, 64, 1, 99, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[223941, 5085, 40, 0, 137, "Section"],

Cell[CellGroupData[{
Cell[224006, 5089, 33, 0, 103, "Subsection"],
Cell[224042, 5091, 106, 3, 63, "Text"],
Cell[224151, 5096, 41, 1, 81, "Input"],

Cell[CellGroupData[{
Cell[224217, 5101, 110, 2, 81, "Input"],
Cell[224330, 5105, 105, 2, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[224472, 5112, 48, 1, 81, "Input"],
Cell[224523, 5115, 293, 8, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[224865, 5129, 42, 0, 103, "Subsection"],
Cell[224910, 5131, 63, 0, 63, "Text"],

Cell[CellGroupData[{
Cell[224998, 5135, 47, 1, 81, "Input"],
Cell[225048, 5138, 72, 1, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225157, 5144, 48, 1, 81, "Input"],
Cell[225208, 5147, 253, 7, 103, "Output"]
}, Open  ]],
Cell[225476, 5157, 114, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[225615, 5164, 49, 1, 81, "Input"],
Cell[225667, 5167, 59, 1, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225763, 5173, 48, 1, 81, "Input"],
Cell[225814, 5176, 242, 8, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[226105, 5190, 68, 0, 103, "Subsection"],
Cell[226176, 5192, 103, 3, 63, "Text"],

Cell[CellGroupData[{
Cell[226304, 5199, 46, 1, 81, "Input"],
Cell[226353, 5202, 42, 1, 79, "Output"]
}, Open  ]],
Cell[226410, 5206, 98, 1, 63, "Text"],

Cell[CellGroupData[{
Cell[226533, 5211, 46, 1, 81, "Input"],
Cell[226582, 5214, 42, 1, 79, "Output"]
}, Open  ]],
Cell[226639, 5218, 147, 3, 102, "Text"],

Cell[CellGroupData[{
Cell[226811, 5225, 55, 1, 81, "Input"],
Cell[226869, 5228, 47, 1, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[226965, 5235, 65, 0, 103, "Subsection"],
Cell[227033, 5237, 148, 3, 102, "Text"],
Cell[227184, 5242, 69, 1, 81, "Input"],

Cell[CellGroupData[{
Cell[227278, 5247, 48, 1, 81, "Input"],
Cell[227329, 5250, 237, 7, 103, "Output"]
}, Open  ]],
Cell[227581, 5260, 96, 2, 63, "Text"],

Cell[CellGroupData[{
Cell[227702, 5266, 62, 1, 81, "Input"],
Cell[227767, 5269, 71, 1, 98, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

